@@ -26,20 +26,25 @@
 #include <glib/gi18n.h>
 
 #include "config.h"
-#include "cairo-dock-module-factory.h"
+#include "gldi-icon-names.h"
+#include "cairo-dock-module-manager.h"  // gldi_module_foreach
+#include "cairo-dock-module-instance-manager.h"
 #include "cairo-dock-log.h"
+#include "cairo-dock-desklet-manager.h"  // cairo_dock_foreach_desklet
 #include "cairo-dock-icon-facility.h"
 #include "cairo-dock-gui-factory.h"
 #include "cairo-dock-keyfile-utilities.h"
 #include "cairo-dock-animations.h"
 #include "cairo-dock-draw.h"
+#include "cairo-dock-stack-icon-manager.h"
+#include "cairo-dock-separator-manager.h"
 #include "cairo-dock-themes-manager.h"
 #include "cairo-dock-dock-manager.h"
 #include "cairo-dock-container.h"
+#include "cairo-dock-menu.h"  // cairo_dock_add_in_menu_with_stock_and_data
 #include "cairo-dock-applications-manager.h"
 #include "cairo-dock-launcher-manager.h"
-#include "cairo-dock-desktop-file-factory.h"
-#include "cairo-dock-X-manager.h"
+#include "cairo-dock-desktop-manager.h"
 #include "cairo-dock-gui-manager.h"
 #include "cairo-dock-gui-commons.h"
 #include "cairo-dock-widget-items.h"
@@ -47,14 +52,13 @@
 #define CAIRO_DOCK_LAUNCHER_PANEL_WIDTH 1200 // matttbe: 800
 #define CAIRO_DOCK_LAUNCHER_PANEL_HEIGHT 700 // matttbe: 500
 #define CAIRO_DOCK_LEFT_PANE_MIN_WIDTH 100
-#define CAIRO_DOCK_LEFT_PANE_DEFAULT_WIDTH 340 // matttbe: 200
+#define CAIRO_DOCK_LEFT_PANE_DEFAULT_WIDTH 300 // matttbe: 200
 #define CAIRO_DOCK_RIGHT_PANE_MIN_WIDTH 800 // matttbe: 500
 
 #define CAIRO_DOCK_ITEM_ICON_SIZE 32
 
 extern gchar *g_cCurrentLaunchersPath;
 extern gchar *g_cCurrentThemePath;
-extern CairoDockDesktopGeometry g_desktopGeometry;
 extern CairoDock *g_pMainDock;
 
 static void _add_one_dock_to_model (CairoDock *pDock, GtkTreeStore *model, GtkTreeIter *pParentIter);
@@ -67,8 +71,8 @@ typedef enum {
 	CD_MODEL_NAME = 0,  // displayed name
 	CD_MODEL_PIXBUF,  // icon image
 	CD_MODEL_ICON,  // Icon (for launcher/separator/sub-dock/applet)
-	CD_MODEL_CONTAINER,  // CairoContainer (for main docks)
-	CD_MODEL_MODULE,  // CairoDockModuleInstance (for plug-ins with no icon)
+	CD_MODEL_CONTAINER,  // GldiContainer (for main docks)
+	CD_MODEL_MODULE,  // GldiModuleInstance (for plug-ins with no icon)
 	CD_MODEL_NB_COLUMNS
 	} CDModelColumns;
 
@@ -157,8 +161,8 @@ static gboolean _on_select_one_item_in_tree (G_GNUC_UNUSED GtkTreeSelection * se
 	// get new current item
 	gchar *cName = NULL;
 	Icon *pIcon = NULL;
-	CairoContainer *pContainer = NULL;
-	CairoDockModuleInstance *pInstance = NULL;
+	GldiContainer *pContainer = NULL;
+	GldiModuleInstance *pInstance = NULL;
 	gtk_tree_model_get (model, &iter,
 		CD_MODEL_NAME, &cName,
 		CD_MODEL_ICON, &pIcon,
@@ -211,14 +215,14 @@ static gboolean _on_select_one_item_in_tree (G_GNUC_UNUSED GtkTreeSelection * se
 		if (!pDock->bIsMainDock)  // pour l'instant le main dock n'a pas de fichier de conf
 		{
 			// build dock's widgets
-			const gchar *cDockName = cairo_dock_search_dock_name (pDock);  // CD_MODEL_NAME contient le nom affiche, qui peut differer.
+			const gchar *cDockName = gldi_dock_get_name (pDock);  // CD_MODEL_NAME contient le nom affiche, qui peut differer.
 			g_return_val_if_fail (cDockName != NULL, FALSE);
 			cd_message ("%s (%s)", __func__, cDockName);
 			
 			gchar *cConfFilePath = g_strdup_printf ("%s/%s.conf", g_cCurrentThemePath, cDockName);
 			if (! g_file_test (cConfFilePath, G_FILE_TEST_EXISTS))  // ne devrait pas arriver mais au cas ou.
 			{
-				cairo_dock_add_root_dock_config_for_name (cDockName);
+				gldi_dock_add_conf_file_for_name (cDockName);
 			}
 			
 			pDataGarbage = g_ptr_array_new ();
@@ -292,11 +296,12 @@ static void _add_one_icon_to_model (Icon *pIcon, GtkTreeStore *model, GtkTreeIte
 	GdkPixbuf *pixbuf = NULL;
 	gchar *cImagePath = NULL;
 	const gchar *cName;
+	int iSize = cairo_dock_search_icon_size (GTK_ICON_SIZE_LARGE_TOOLBAR);
 	
 	// set an image.
 	if (pIcon->cFileName != NULL)
 	{
-		cImagePath = cairo_dock_search_icon_s_path (pIcon->cFileName, CAIRO_DOCK_ITEM_ICON_SIZE);
+		cImagePath = cairo_dock_search_icon_s_path (pIcon->cFileName, iSize);
 	}
 	if (cImagePath == NULL || ! g_file_test (cImagePath, G_FILE_TEST_EXISTS))
 	{
@@ -308,7 +313,7 @@ static void _add_one_icon_to_model (Icon *pIcon, GtkTreeStore *model, GtkTreeIte
 		}
 		else if (CAIRO_DOCK_IS_APPLET (pIcon))
 		{
-			cImagePath = g_strdup (pIcon->pModuleInstance->pModule->pVisitCard->cIconFilePath);
+			cImagePath = cairo_dock_search_icon_s_path (pIcon->pModuleInstance->pModule->pVisitCard->cIconFilePath, iSize);
 		}
 		else
 		{
@@ -323,7 +328,7 @@ static void _add_one_icon_to_model (Icon *pIcon, GtkTreeStore *model, GtkTreeIte
 	
 	if (cImagePath != NULL)
 	{
-		pixbuf = gdk_pixbuf_new_from_file_at_size (cImagePath, CAIRO_DOCK_ITEM_ICON_SIZE, CAIRO_DOCK_ITEM_ICON_SIZE, &erreur);
+		pixbuf = gdk_pixbuf_new_from_file_at_size (cImagePath, iSize, iSize, &erreur);
 		if (erreur != NULL)
 		{
 			cd_warning (erreur->message);
@@ -370,17 +375,15 @@ static void _add_one_dock_to_model (CairoDock *pDock, GtkTreeStore *model, GtkTr
 	}
 }
 
-static void _add_one_root_dock_to_model (const gchar *cName, CairoDock *pDock, GtkTreeStore *model)
+static void _add_one_root_dock_to_model (CairoDock *pDock, GtkTreeStore *model)
 {
-	if (pDock->iRefCount != 0)
-		return ;
 	GtkTreeIter iter;
 	
 	// on ajoute une ligne pour le dock.
 	gtk_tree_store_append (model, &iter, NULL);
-	gchar *cUserName = cairo_dock_get_readable_name_for_fock (pDock);
+	gchar *cUserName = gldi_dock_get_readable_name (pDock);
 	gtk_tree_store_set (model, &iter,
-		CD_MODEL_NAME, cUserName ? cUserName : cName,
+		CD_MODEL_NAME, cUserName ? cUserName : gldi_dock_get_name (pDock),
 		CD_MODEL_CONTAINER, pDock,
 		-1);
 	g_free (cUserName);
@@ -400,15 +403,16 @@ static gboolean _add_one_desklet_to_model (CairoDesklet *pDesklet, GtkTreeStore
 	return FALSE; // FALSE => keep going
 }
 
-static inline void _add_one_module (G_GNUC_UNUSED const gchar *cModuleName, CairoDockModuleInstance *pModuleInstance, GtkTreeStore *model)
+static inline void _add_one_module (G_GNUC_UNUSED const gchar *cModuleName, GldiModuleInstance *pModuleInstance, GtkTreeStore *model)
 {
 	GtkTreeIter iter;
 	gtk_tree_store_append (model, &iter, NULL);
 	
 	GdkPixbuf *pixbuf = NULL;
-	gchar *cImagePath = g_strdup (pModuleInstance->pModule->pVisitCard->cIconFilePath);
+	int iSize = cairo_dock_search_icon_size (GTK_ICON_SIZE_LARGE_TOOLBAR);
+	gchar *cImagePath = cairo_dock_search_icon_s_path (pModuleInstance->pModule->pVisitCard->cIconFilePath, iSize);
 	if (cImagePath != NULL)
-		pixbuf = gdk_pixbuf_new_from_file_at_size (cImagePath, CAIRO_DOCK_ITEM_ICON_SIZE, CAIRO_DOCK_ITEM_ICON_SIZE, NULL);
+		pixbuf = gdk_pixbuf_new_from_file_at_size (cImagePath, iSize, iSize, NULL);
 	gtk_tree_store_set (model, &iter,
 		CD_MODEL_NAME, pModuleInstance->pModule->pVisitCard->cTitle,
 		CD_MODEL_PIXBUF, pixbuf,
@@ -418,17 +422,16 @@ static inline void _add_one_module (G_GNUC_UNUSED const gchar *cModuleName, Cair
 	if (pixbuf)
 		g_object_unref (pixbuf);
 }
-static gboolean _add_one_module_to_model (const gchar *cModuleName, CairoDockModule *pModule, GtkTreeStore *model)
+static gboolean _add_one_module_to_model (const gchar *cModuleName, GldiModule *pModule, GtkTreeStore *model)
 {
-	if (pModule->pVisitCard->iCategory != CAIRO_DOCK_CATEGORY_BEHAVIOR && pModule->pVisitCard->iCategory != CAIRO_DOCK_CATEGORY_THEME && ! cairo_dock_module_is_auto_loaded (pModule))
+	if (pModule->pVisitCard->iCategory != CAIRO_DOCK_CATEGORY_BEHAVIOR && pModule->pVisitCard->iCategory != CAIRO_DOCK_CATEGORY_THEME && ! gldi_module_is_auto_loaded (pModule))
 	{
 		GList *pItem;
 		for (pItem = pModule->pInstancesList; pItem != NULL; pItem = pItem->next)
 		{
-			CairoDockModuleInstance *pModuleInstance = pItem->data;
-			if (pModuleInstance->pIcon == NULL || (pModuleInstance->pDock && !pModuleInstance->pIcon->cParentDockName))
+			GldiModuleInstance *pModuleInstance = pItem->data;
+			if (pModuleInstance->pIcon == NULL || (pModuleInstance->pDock && cairo_dock_get_icon_container(pModuleInstance->pIcon) == NULL))  // either a plug-in or a detached applet -> add a line for it
 			{
-				// on ajoute une ligne pour l'applet.
 				_add_one_module (cModuleName, pModuleInstance, model);
 			}
 		}
@@ -436,7 +439,7 @@ static gboolean _add_one_module_to_model (const gchar *cModuleName, CairoDockMod
 	return FALSE; // FALSE => keep going
 }
 
-static void _select_item (ItemsWidget *pItemsWidget, Icon *pIcon, CairoContainer *pContainer, CairoDockModuleInstance *pModuleInstance)
+static void _select_item (ItemsWidget *pItemsWidget, Icon *pIcon, GldiContainer *pContainer, GldiModuleInstance *pModuleInstance)
 {
 	g_free (pItemsWidget->cPrevPath);
 	pItemsWidget->cPrevPath = NULL;
@@ -468,15 +471,15 @@ static GtkTreeModel *_build_tree_model (ItemsWidget *pItemsWidget)
 		G_TYPE_POINTER,  // Icon
 		G_TYPE_POINTER,  // Container
 		G_TYPE_POINTER);  // Module
-	cairo_dock_foreach_docks ((GHFunc) _add_one_root_dock_to_model, model);  // on n'utilise pas cairo_dock_foreach_root_docks(), de facon a avoir le nom du dock.
-	cairo_dock_foreach_desklet ((CairoDockForeachDeskletFunc) _add_one_desklet_to_model, model);
-	cairo_dock_foreach_module ((GHRFunc)_add_one_module_to_model, model);
-	/*CairoDockModule *pModule = cairo_dock_find_module_from_name ("Help");
+	gldi_docks_foreach_root ((GFunc) _add_one_root_dock_to_model, model);  // add all docks, with their icons
+	gldi_desklets_foreach ((GldiDeskletForeachFunc) _add_one_desklet_to_model, model);  // add all desklets
+	gldi_module_foreach ((GHRFunc)_add_one_module_to_model, model);  // add all modules that are neither in a dock nor a desklet (plug-ins or detached applets)
+	/*GldiModule *pModule = gldi_module_get ("Help");
 	if (pModule != NULL)
 	{
 		if (pModule->pInstancesList == NULL)  // Help is not active, so is not already in the icons list.
 		{
-			///CairoDockModuleInstance *pModuleInstance = pModule->pInstancesList->data;
+			///GldiModuleInstance *pModuleInstance = pModule->pInstancesList->data;
 			///_add_one_module ("Help", pModuleInstance, model);
 			/// add it ...
 		}
@@ -517,8 +520,8 @@ static void on_row_deleted (GtkTreeModel *model, G_GNUC_UNUSED GtkTreePath *path
 			// get the item that has been moved.
 			gchar *cName = NULL;
 			Icon *pIcon = NULL;
-			CairoContainer *pContainer = NULL;
-			CairoDockModuleInstance *pInstance = NULL;
+			GldiContainer *pContainer = NULL;
+			GldiModuleInstance *pInstance = NULL;
 			gtk_tree_model_get (model, &lastInsertedIter,
 				CD_MODEL_NAME, &cName,
 				CD_MODEL_ICON, &pIcon,
@@ -528,15 +531,15 @@ static void on_row_deleted (GtkTreeModel *model, G_GNUC_UNUSED GtkTreePath *path
 			if (pIcon)  // launcher/separator/sub-dock-icon or applet
 			{
 				// get the icon and container.
-				/**if (pIcon == NULL)
-					pIcon = pInstance->pIcon;*/
 				if (pContainer == NULL)
 				{
-					if (pInstance != NULL)
-						pContainer = pInstance->pContainer;
-					else if (pIcon != NULL)
+					pContainer = cairo_dock_get_icon_container(pIcon);
+					if (pContainer == NULL)  // detached icon
 					{
-						pContainer = CAIRO_CONTAINER (cairo_dock_search_dock_from_name (pIcon->cParentDockName));
+						if (pInstance != NULL)
+							pContainer = pInstance->pContainer;
+						else
+							pContainer = CAIRO_CONTAINER (gldi_dock_get (pIcon->cParentDockName));  // hidden icon (for instance a launcher on a given workspace; we can change that if we make a 'hide' function in the docks)
 					}
 				}
 				
@@ -547,7 +550,7 @@ static void on_row_deleted (GtkTreeModel *model, G_GNUC_UNUSED GtkTreePath *path
 				{
 					gchar *cParentName = NULL;
 					Icon *pParentIcon = NULL;
-					CairoContainer *pParentContainer = NULL;
+					GldiContainer *pParentContainer = NULL;
 					gtk_tree_model_get (model, &parent_iter,
 						CD_MODEL_NAME, &cParentName,
 						CD_MODEL_ICON, &pParentIcon,
@@ -561,7 +564,9 @@ static void on_row_deleted (GtkTreeModel *model, G_GNUC_UNUSED GtkTreePath *path
 						}
 						else  // not an icon that can contain our item, so place it next to it.
 						{
-							pParentContainer = CAIRO_CONTAINER (cairo_dock_search_dock_from_name (pParentIcon->cParentDockName));
+							pParentContainer = cairo_dock_get_icon_container (pParentIcon);
+							if (!pParentContainer)  // detached icon
+								pParentContainer = CAIRO_CONTAINER (gldi_dock_get (pParentIcon->cParentDockName));  // hidden icon
 							// we'll search the parent instead.
 							lastInsertedIter = parent_iter;
 							gtk_tree_model_iter_parent (model, &parent_iter, &lastInsertedIter);
@@ -572,10 +577,10 @@ static void on_row_deleted (GtkTreeModel *model, G_GNUC_UNUSED GtkTreePath *path
 						// if it has changed, update the conf file and the icon.
 						if (pParentContainer != pContainer)
 						{
-							const gchar *cNewParentDockName = cairo_dock_search_dock_name (CAIRO_DOCK (pParentContainer));
+							const gchar *cNewParentDockName = gldi_dock_get_name (CAIRO_DOCK (pParentContainer));
 							if (cNewParentDockName != NULL)
 							{
-								cairo_dock_write_container_name_in_conf_file (pIcon, cNewParentDockName);
+								gldi_theme_icon_write_container_name_in_conf_file (pIcon, cNewParentDockName);
 							}
 							
 							if ((CAIRO_DOCK_ICON_TYPE_IS_LAUNCHER (pIcon)
@@ -583,11 +588,11 @@ static void on_row_deleted (GtkTreeModel *model, G_GNUC_UNUSED GtkTreePath *path
 								|| CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (pIcon))
 							&& pIcon->cDesktopFileName != NULL)  // user icon.
 							{
-								cairo_dock_reload_launcher (pIcon);
+								gldi_object_reload (GLDI_OBJECT(pIcon), TRUE);  // TRUE <=> reload config.
 							}
 							else if (CAIRO_DOCK_IS_APPLET (pIcon))
 							{
-								cairo_dock_reload_module_instance (pIcon->pModuleInstance, TRUE);  // TRUE <=> reload config.
+								gldi_object_reload (GLDI_OBJECT(pIcon->pModuleInstance), TRUE);  // TRUE <=> reload config.
 							}
 						}
 						
@@ -663,8 +668,8 @@ static void _on_select_remove_item (G_GNUC_UNUSED GtkMenuItem *pMenuItem, GtkWid
 	
 	// get the corresponding item, and the next line.
 	Icon *pIcon = NULL;
-	CairoContainer *pContainer = NULL;
-	CairoDockModuleInstance *pInstance = NULL;
+	GldiContainer *pContainer = NULL;
+	GldiModuleInstance *pInstance = NULL;
 	gtk_tree_model_get (pModel, &iter,
 		CD_MODEL_ICON, &pIcon,
 		CD_MODEL_CONTAINER, &pContainer,
@@ -676,27 +681,21 @@ static void _on_select_remove_item (G_GNUC_UNUSED GtkMenuItem *pMenuItem, GtkWid
 	// remove it.
 	if (CAIRO_DOCK_ICON_TYPE_IS_LAUNCHER (pIcon)
 		|| CAIRO_DOCK_ICON_TYPE_IS_CONTAINER (pIcon)
-		|| CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (pIcon))  // launcher/separator/sub-dock
-	{
-		cairo_dock_trigger_icon_removal_from_dock (pIcon);
-	}
-	else if (CAIRO_DOCK_IS_APPLET (pIcon))  // applet
+		|| CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (pIcon)
+		|| CAIRO_DOCK_IS_APPLET (pIcon))  // icon
 	{
 		cairo_dock_trigger_icon_removal_from_dock (pIcon);
 	}
 	else if (pInstance != NULL)  // plug-in
 	{
-		cairo_dock_remove_module_instance (pInstance);
+		gldi_object_delete (GLDI_OBJECT(pInstance));
 	}
-	else if (CAIRO_DOCK_IS_DOCK (pContainer))  // main-dock
+	else if (CAIRO_DOCK_IS_DOCK (pContainer))  // root dock
 	{
 		CairoDock *pDock = CAIRO_DOCK (pContainer);
 		if (! pDock->bIsMainDock)
 		{
-			cairo_dock_remove_icons_from_dock (pDock, NULL, NULL);
-		
-			const gchar *cDockName = cairo_dock_search_dock_name (pDock);
-			cairo_dock_destroy_dock (pDock, cDockName);
+			gldi_object_delete (GLDI_OBJECT(pDock));
 		}
 	}
 	
@@ -722,7 +721,7 @@ static gboolean on_button_press_event (GtkWidget *pTreeView,
 		GtkWidget *pMenu = gtk_menu_new ();
 		
 		/// TODO: check that we can actually remove it (ex.: not the main dock), and maybe display the item's name...
-		cairo_dock_add_in_menu_with_stock_and_data (_("Remove this item"), GTK_STOCK_REMOVE, G_CALLBACK (_on_select_remove_item), pMenu, pTreeView);
+		cairo_dock_add_in_menu_with_stock_and_data (_("Remove this item"), GLDI_ICON_NAME_REMOVE, G_CALLBACK (_on_select_remove_item), pMenu, pTreeView);
 		
 		gtk_widget_show_all (pMenu);
 		
@@ -743,11 +742,7 @@ ItemsWidget *cairo_dock_items_widget_new (GtkWindow *pMainWindow)
 	pItemsWidget->widget.iType = WIDGET_ITEMS;
 	
 	GtkWidget *pLauncherPane;
-	#if (GTK_MAJOR_VERSION < 3)
-	pLauncherPane = gtk_hpaned_new ();
-	#else
 	pLauncherPane = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
-	#endif
 	pItemsWidget->widget.pWidget = pLauncherPane;
 	pItemsWidget->widget.apply = _items_widget_apply;
 	pItemsWidget->widget.reset = _items_widget_reset;
@@ -786,12 +781,16 @@ ItemsWidget *cairo_dock_items_widget_new (GtkWindow *pMainWindow)
 	
 	GtkWidget *pLauncherWindow = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (pLauncherWindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+	#if GTK_CHECK_VERSION (3, 8, 0)
+	gtk_container_add (GTK_CONTAINER (pLauncherWindow), pItemsWidget->pTreeView);
+	#else
 	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (pLauncherWindow), pItemsWidget->pTreeView);
+	#endif
 	gtk_paned_pack1 (GTK_PANED (pLauncherPane), pLauncherWindow, TRUE, FALSE);
 	
 	//\_____________ On essaie de definir une taille correcte.
-	int w = MIN (CAIRO_DOCK_LAUNCHER_PANEL_WIDTH, gldi_get_desktop_width());
-	if (gldi_get_desktop_width() < CAIRO_DOCK_LAUNCHER_PANEL_WIDTH)  // ecran trop petit, on va essayer de reserver au moins R pixels pour le panneau de droite (avec un minimum de L pixels pour celui de gauche).
+	int w = MIN (CAIRO_DOCK_LAUNCHER_PANEL_WIDTH, gldi_desktop_get_width());
+	if (gldi_desktop_get_width() < CAIRO_DOCK_LAUNCHER_PANEL_WIDTH)  // ecran trop petit, on va essayer de reserver au moins R pixels pour le panneau de droite (avec un minimum de L pixels pour celui de gauche).
 		gtk_paned_set_position (GTK_PANED (pLauncherPane), MAX (CAIRO_DOCK_LEFT_PANE_MIN_WIDTH, w - CAIRO_DOCK_RIGHT_PANE_MIN_WIDTH));
 	else  // we set a default width rather than letting GTK guess the best, because the right panel is more important than the left one.
 		gtk_paned_set_position (GTK_PANED (pLauncherPane), CAIRO_DOCK_LEFT_PANE_DEFAULT_WIDTH);
@@ -805,8 +804,8 @@ static void _items_widget_apply (CDWidget *pCdWidget)
 {
 	ItemsWidget *pItemsWidget = ITEMS_WIDGET (pCdWidget);
 	Icon *pIcon = pItemsWidget->pCurrentIcon;
-	CairoContainer *pContainer = pItemsWidget->pCurrentContainer;
-	CairoDockModuleInstance *pModuleInstance = pItemsWidget->pCurrentModuleInstance;
+	GldiContainer *pContainer = pItemsWidget->pCurrentContainer;
+	GldiModuleInstance *pModuleInstance = pItemsWidget->pCurrentModuleInstance;
 	
 	if (CAIRO_DOCK_IS_APPLET (pIcon))
 		pModuleInstance = pIcon->pModuleInstance;
@@ -829,10 +828,10 @@ static void _items_widget_apply (CDWidget *pCdWidget)
 			gboolean bIsDetached = g_key_file_get_boolean (pKeyFile, "Desklet", "initially detached", NULL);
 			if (!bIsDetached)
 			{
-				CairoDock *pDock = cairo_dock_search_dock_from_name (cDockName);
+				CairoDock *pDock = gldi_dock_get (cDockName);
 				if (pDock == NULL)
 				{
-					gchar *cNewDockName = cairo_dock_add_root_dock_config ();
+					gchar *cNewDockName = gldi_dock_add_conf_file ();
 					g_key_file_set_string (pKeyFile, "Icon", "dock name", cNewDockName);
 					g_free (cNewDockName);
 				}
@@ -848,16 +847,15 @@ static void _items_widget_apply (CDWidget *pCdWidget)
 		g_key_file_free (pKeyFile);
 		
 		// reload module.
-		cairo_dock_reload_module_instance (pModuleInstance, TRUE);
+		gldi_object_reload (GLDI_OBJECT(pModuleInstance), TRUE);
 	}
 	else if (CAIRO_DOCK_IS_DOCK (pContainer))
 	{
 		CairoDock *pDock = CAIRO_DOCK (pContainer);
 		if (!pDock->bIsMainDock)  // pour l'instant le main dock n'a pas de fichier de conf
 		{
-			const gchar *cDockName = cairo_dock_search_dock_name (pDock);  // CD_MODEL_NAME contient le nom affiche, qui peut differer.
+			const gchar *cDockName = gldi_dock_get_name (pDock);
 			g_return_if_fail (cDockName != NULL);
-			
 			gchar *cConfFilePath = g_strdup_printf ("%s/%s.conf", g_cCurrentThemePath, cDockName);
 			
 			// open the conf file.
@@ -873,7 +871,7 @@ static void _items_widget_apply (CDWidget *pCdWidget)
 			g_free (cConfFilePath);
 			
 			// reload dock's config.
-			cairo_dock_reload_one_root_dock (cDockName, pDock);
+			gldi_object_reload (GLDI_OBJECT(pDock), TRUE);
 		}
 	}
 	else if (pIcon)
@@ -891,10 +889,10 @@ static void _items_widget_apply (CDWidget *pCdWidget)
 		if (g_key_file_has_key (pKeyFile, "Desktop Entry", "Container", NULL))
 		{
 			gchar *cDockName = g_key_file_get_string (pKeyFile, "Desktop Entry", "Container", NULL);
-			CairoDock *pDock = cairo_dock_search_dock_from_name (cDockName);
+			CairoDock *pDock = gldi_dock_get (cDockName);
 			if (pDock == NULL)
 			{
-				gchar *cNewDockName = cairo_dock_add_root_dock_config ();
+				gchar *cNewDockName = gldi_dock_add_conf_file ();
 				g_key_file_set_string (pKeyFile, "Icon", "dock name", cNewDockName);
 				g_free (cNewDockName);
 			}
@@ -907,7 +905,7 @@ static void _items_widget_apply (CDWidget *pCdWidget)
 		g_free (cConfFilePath);
 		
 		// reload widgets.
-		cairo_dock_reload_launcher (pIcon);  // prend tout en compte, y compris le redessin et declenche le rechargement de l'IHM.
+		gldi_object_reload (GLDI_OBJECT(pIcon), TRUE);  // prend tout en compte, y compris le redessin et declenche le rechargement de l'IHM.
 	}
 	_items_widget_reload (CD_WIDGET (pItemsWidget));  // we reload in case the items place has changed (icon's container, dock orientation, etc).
 }
@@ -917,7 +915,7 @@ static void _items_widget_apply (CDWidget *pCdWidget)
  /// WIDGET API ///
 //////////////////
 
-void cairo_dock_items_widget_select_item (ItemsWidget *pItemsWidget, Icon *pIcon, CairoContainer *pContainer, CairoDockModuleInstance *pModuleInstance, int iNotebookPage)
+void cairo_dock_items_widget_select_item (ItemsWidget *pItemsWidget, Icon *pIcon, GldiContainer *pContainer, GldiModuleInstance *pModuleInstance, int iNotebookPage)
 {
 	_delete_current_launcher_widget (pItemsWidget);  // pItemsWidget->pCurrentLauncherWidget <- 0
 	
@@ -948,8 +946,8 @@ static void _items_widget_reload (CDWidget *pCdWidget)
 	
 	// reload the current icon/container's widgets by reselecting the current line.
 	Icon *pCurrentIcon = pItemsWidget->pCurrentIcon;
-	CairoContainer *pCurrentContainer = pItemsWidget->pCurrentContainer;
-	CairoDockModuleInstance *pCurrentModuleInstance = pItemsWidget->pCurrentModuleInstance;
+	GldiContainer *pCurrentContainer = pItemsWidget->pCurrentContainer;
+	GldiModuleInstance *pCurrentModuleInstance = pItemsWidget->pCurrentModuleInstance;
 	
 	_delete_current_launcher_widget (pItemsWidget);  // pItemsWidget->pCurrentLauncherWidget <- 0
 	
@@ -993,7 +991,7 @@ void cairo_dock_items_widget_update_desklet_visibility_params (ItemsWidget *pIte
 	cairo_dock_update_desklet_visibility_widgets (pDesklet, pWidgetList);
 }
 
-void cairo_dock_items_widget_update_module_instance_container (ItemsWidget *pItemsWidget, CairoDockModuleInstance *pInstance, gboolean bDetached)
+void cairo_dock_items_widget_update_module_instance_container (ItemsWidget *pItemsWidget, GldiModuleInstance *pInstance, gboolean bDetached)
 {
 	g_return_if_fail (pItemsWidget != NULL);
 	// check that it's about the current item
@@ -1009,14 +1007,14 @@ void cairo_dock_items_widget_update_module_instance_container (ItemsWidget *pIte
 	cairo_dock_update_is_detached_widget (bDetached, pWidgetList);
 }
 
-void cairo_dock_items_widget_reload_current_widget (ItemsWidget *pItemsWidget, CairoDockModuleInstance *pInstance, int iShowPage)
+void cairo_dock_items_widget_reload_current_widget (ItemsWidget *pItemsWidget, GldiModuleInstance *pInstance, int iShowPage)
 {
 	g_return_if_fail (pItemsWidget != NULL && pItemsWidget->pTreeView != NULL);
 	cd_debug ("%s ()", __func__);
 	
 	// check that it's about the current item
 	Icon *pIcon = pItemsWidget->pCurrentIcon;
-	CairoDockModuleInstance *pModuleInstance = pItemsWidget->pCurrentModuleInstance;
+	GldiModuleInstance *pModuleInstance = pItemsWidget->pCurrentModuleInstance;
 	if (pInstance)
 	{
 		if (pIcon)
