@@ -24,19 +24,22 @@
 #include <glib/gi18n.h>
 
 #include "config.h"
+#include "gldi-icon-names.h"
 #include "cairo-dock-struct.h"
 #include "cairo-dock-keyfile-utilities.h"
 #include "cairo-dock-file-manager.h"  // cairo_dock_copy_file
 #include "cairo-dock-packages.h"
 #include "cairo-dock-surface-factory.h"
-#include "cairo-dock-dialog-manager.h"  // cairo_dock_show_dialog_and_wait
+#include "cairo-dock-dialog-factory.h"  // gldi_dialog_show_and_wait
 #include "cairo-dock-gui-factory.h"
 #include "cairo-dock-log.h"
+#include "cairo-dock-icon-facility.h"  // gldi_icons_get_any_without_dialog
 #include "cairo-dock-task.h"
-#include "cairo-dock-dock-manager.h"  // cairo_dock_search_dock_from_name
+#include "cairo-dock-dock-manager.h"  // gldi_dock_get
 #include "cairo-dock-applications-manager.h"  // cairo_dock_get_current_active_icon
 #include "cairo-dock-themes-manager.h"  // cairo_dock_export_current_theme
 #include "cairo-dock-config.h"  // cairo_dock_load_current_theme
+#include "cairo-dock-menu.h"  // cairo_dock_add_in_menu_with_stock_and_data
 #include "cairo-dock-gui-manager.h"  // cairo_dock_set_status_message
 #include "cairo-dock-gui-backend.h"
 #include "cairo-dock-widget-themes.h"
@@ -86,7 +89,7 @@ static void _load_theme (gboolean bSuccess, ThemesWidget *pThemesWidget)
 		cairo_dock_set_status_message (NULL, _("Could not import the theme."));
 	gtk_widget_destroy (pThemesWidget->pWaitingDialog);
 	pThemesWidget->pWaitingDialog = NULL;
-	cairo_dock_discard_task (pThemesWidget->pImportTask);
+	gldi_task_discard (pThemesWidget->pImportTask);
 	pThemesWidget->pImportTask = NULL;
 }
 
@@ -113,7 +116,9 @@ static gchar * _cairo_dock_save_current_theme (GKeyFile* pKeyFile)
 	
 	if (g_key_file_get_boolean (pKeyFile, cGroupName, "package", NULL))
 	{
-		bThemeSaved |= cairo_dock_package_current_theme (cNewThemeName);
+		gchar *cDirPath = g_key_file_get_string (pKeyFile, cGroupName, "package dir", NULL);
+		bThemeSaved |= cairo_dock_package_current_theme (cNewThemeName, cDirPath);
+		g_free (cDirPath);
 	}
 	
 	if (bThemeSaved)
@@ -130,7 +135,7 @@ static gchar * _cairo_dock_save_current_theme (GKeyFile* pKeyFile)
 
 static void on_cancel_dl (G_GNUC_UNUSED GtkButton *button, ThemesWidget *pThemesWidget)
 {
-	cairo_dock_discard_task (pThemesWidget->pImportTask);
+	gldi_task_discard (pThemesWidget->pImportTask);
 	pThemesWidget->pImportTask = NULL;
 	gtk_widget_destroy (pThemesWidget->pWaitingDialog);  // stop the pulse too
 	pThemesWidget->pWaitingDialog = NULL;
@@ -176,15 +181,17 @@ static gboolean _cairo_dock_load_theme (GKeyFile* pKeyFile, ThemesWidget *pTheme
 	
 	if (pThemesWidget->pImportTask != NULL)
 	{
-		cairo_dock_discard_task (pThemesWidget->pImportTask);
+		gldi_task_discard (pThemesWidget->pImportTask);
 		pThemesWidget->pImportTask = NULL;
 	}
 	//\___________________ On regarde si le theme courant est modifie.
 	gboolean bNeedSave = cairo_dock_current_theme_need_save ();
 	if (bNeedSave)
 	{
-		Icon *pIcon = cairo_dock_get_dialogless_icon ();
-		int iClickedButton = cairo_dock_show_dialog_and_wait (_("You have made some changes to the current theme.\nYou will lose them if you don't save before choosing a new theme. Continue anyway?"),
+		Icon *pIcon = cairo_dock_get_current_active_icon ();  // it's most probably the icon corresponding to the configuration window
+		if (pIcon == NULL || cairo_dock_get_icon_container (pIcon) == NULL)  // if not available, get any icon
+			pIcon = gldi_icons_get_any_without_dialog ();
+		int iClickedButton = gldi_dialog_show_and_wait (_("You have made some changes to the current theme.\nYou will lose them if you don't save before choosing a new theme. Continue anyway?"),
 			pIcon, CAIRO_CONTAINER (g_pMainDock),
 			CAIRO_DOCK_SHARE_DATA_DIR"/"CAIRO_DOCK_ICON, NULL);
 		if (iClickedButton != 0 && iClickedButton != -1)  // cancel button or Escape.
@@ -209,7 +216,7 @@ static gboolean _cairo_dock_load_theme (GKeyFile* pKeyFile, ThemesWidget *pTheme
 		gtk_window_set_transient_for (GTK_WINDOW (pWaitingDialog), pMainWindow);
 		gtk_window_set_modal (GTK_WINDOW (pWaitingDialog), TRUE);
 
-		GtkWidget *pMainVBox = _gtk_vbox_new (CAIRO_DOCK_FRAME_MARGIN);
+		GtkWidget *pMainVBox = gtk_box_new (GTK_ORIENTATION_VERTICAL, CAIRO_DOCK_FRAME_MARGIN);
 		gtk_container_add (GTK_CONTAINER (pWaitingDialog), pMainVBox);
 		
 		GtkWidget *pLabel = gtk_label_new (_("Please wait while importing the theme..."));
@@ -224,7 +231,7 @@ static gboolean _cairo_dock_load_theme (GKeyFile* pKeyFile, ThemesWidget *pTheme
 			G_CALLBACK (on_waiting_dialog_destroyed),
 			pThemesWidget);
 		
-		GtkWidget *pCancelButton = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
+		GtkWidget *pCancelButton = gtk_button_new_with_label (_("Cancel"));
 		g_signal_connect (G_OBJECT (pCancelButton), "clicked", G_CALLBACK(on_cancel_dl), pWaitingDialog);
 		gtk_box_pack_start (GTK_BOX (pMainVBox), pCancelButton, FALSE, FALSE, 0);
 		
@@ -366,14 +373,12 @@ static void _change_rating (G_GNUC_UNUSED GtkCellRendererText * cell, gchar * pa
 	}
 	else
 	{
-		Icon *pIcon = cairo_dock_get_current_active_icon ();
-		CairoDock *pDock = NULL;
-		if (pIcon != NULL)
-			pDock = cairo_dock_search_dock_from_name (pIcon->cParentDockName);
-		if (pDock != NULL)
-			cairo_dock_show_temporary_dialog_with_icon (_("You must try the theme before you can rate it."), pIcon, CAIRO_CONTAINER (pDock), 3000, "same icon");
+		Icon *pIcon = cairo_dock_get_current_active_icon ();  // most probably the appli-icon representing the config window.
+		GldiContainer *pContainer = (pIcon != NULL ? cairo_dock_get_icon_container (pIcon) : NULL);
+		if (pContainer != NULL)
+			gldi_dialog_show_temporary_with_icon (_("You must try the theme before you can rate it."), pIcon, pContainer, 3000, "same icon");
 		else
-			cairo_dock_show_general_message (_("You must try the theme before you can rate it."), 3000);
+			gldi_dialog_show_general_message (_("You must try the theme before you can rate it."), 3000);
 	}
 	g_free (cThemeName);
 	g_free (cRatingFile);
@@ -390,7 +395,7 @@ static void _got_themes_list (GHashTable *pThemeTable, ThemesWidget *pThemesWidg
 	else
 		cairo_dock_set_status_message (GTK_WIDGET (pThemesWidget->pMainWindow), "");
 	
-	cairo_dock_discard_task (pThemesWidget->pListTask);
+	gldi_task_discard (pThemesWidget->pListTask);
 	pThemesWidget->pListTask = NULL;
 	
 	GtkListStore *pModel = GTK_LIST_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (pThemesWidget->pTreeView)));
@@ -450,7 +455,7 @@ static gboolean _on_click_tree_view (GtkTreeView *pTreeView, GdkEventButton* pBu
 			{
 				GtkWidget *pMenu = gtk_menu_new ();
 				
-				cairo_dock_add_in_menu_with_stock_and_data (_("Delete this theme"), GTK_STOCK_DELETE, G_CALLBACK (_on_delete_theme), pMenu, pThemesWidget);
+				cairo_dock_add_in_menu_with_stock_and_data (_("Delete this theme"), GLDI_ICON_NAME_DELETE, G_CALLBACK (_on_delete_theme), pMenu, pThemesWidget);
 				
 				gtk_widget_show_all (pMenu);
 				gtk_menu_popup (GTK_MENU (pMenu),
@@ -531,14 +536,18 @@ static void _make_tree_view_for_themes (ThemesWidget *pThemesWidget, GPtrArray *
 	pThemesWidget->pTreeView = pOneWidget;
 	GtkWidget *pScrolledWindow = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (pScrolledWindow), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+	#if GTK_CHECK_VERSION (3, 8, 0)
+	gtk_container_add (GTK_CONTAINER (pScrolledWindow), pOneWidget);
+	#else
 	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (pScrolledWindow), pOneWidget);
+	#endif
 	// menu
 	g_signal_connect (G_OBJECT (pOneWidget), "button-release-event", G_CALLBACK (_on_click_tree_view), pThemesWidget);
 	g_signal_connect (G_OBJECT (pOneWidget), "button-press-event", G_CALLBACK (_on_click_tree_view), pThemesWidget);
 	
 	//\______________ add a preview widget next to the treeview
 	GtkWidget *pPreviewBox = cairo_dock_gui_make_preview_box (GTK_WIDGET (pThemesWidget->pMainWindow), pOneWidget, FALSE, 2, NULL, CAIRO_DOCK_SHARE_DATA_DIR"/images/"CAIRO_DOCK_LOGO, pDataGarbage);
-	GtkWidget *pWidgetBox = _gtk_hbox_new (CAIRO_DOCK_GUI_MARGIN);
+	GtkWidget *pWidgetBox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, CAIRO_DOCK_GUI_MARGIN);
 	gtk_box_pack_start (GTK_BOX (pWidgetBox), pScrolledWindow, TRUE, TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (pWidgetBox), pPreviewBox, TRUE, TRUE, 0);
 	
@@ -582,12 +591,12 @@ static void _make_combo_for_user_themes (ThemesWidget *pThemesWidget, GPtrArray
 	_fill_combo_with_user_themes (pThemesWidget);
 	
 	//\______________ insert the widget.
-	GtkWidget *pHBox = _gtk_hbox_new (CAIRO_DOCK_GUI_MARGIN);
+	GtkWidget *pHBox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, CAIRO_DOCK_GUI_MARGIN);
 	GtkWidget *pLabel = gtk_label_new (_("Save as:"));
 	
 	//\______________ add a preview widget under to the combo
 	GtkWidget *pPreviewBox = cairo_dock_gui_make_preview_box (GTK_WIDGET (pThemesWidget->pMainWindow), pOneWidget, FALSE, 1, NULL, NULL, pDataGarbage);
-	GtkWidget *pWidgetBox = _gtk_vbox_new (CAIRO_DOCK_GUI_MARGIN);
+	GtkWidget *pWidgetBox = gtk_box_new (GTK_ORIENTATION_VERTICAL, CAIRO_DOCK_GUI_MARGIN);
 	
 	GtkWidget *pAlign = gtk_alignment_new (0, 0, 1, 0);
 	gtk_container_add (GTK_CONTAINER (pAlign), pLabel);
@@ -692,7 +701,7 @@ static void _themes_widget_reset (CDWidget *pCdWidget)
 	g_remove (pThemesWidget->cInitConfFile);
 	g_free (pThemesWidget->cInitConfFile);
 	
-	cairo_dock_discard_task (pThemesWidget->pImportTask);
+	gldi_task_discard (pThemesWidget->pImportTask);
 	
 	if (pThemesWidget->iSidPulse != 0)
 		g_source_remove (pThemesWidget->iSidPulse);
