@@ -37,18 +37,15 @@
 **    Karl Lattimer <karl@qdh.org.uk>
 ** Originally conceived as a stress-test for cairo, librsvg, and glitz.
 **
-*********************** VERSION 0.1 and above (2007-2013) *********************
+*********************** VERSION 0.1 and above (2007-2014) *********************
 **
 ** author(s) :
 **     Fabrice Rey <fabounet@glx-dock.org>
 ** With the help of:
-**     A lot of people !!!
+**     A lot of people !!! (see the About menu and the 'copyright' file)
 **
 *******************************************************************************/
 
-/// http://www.siteduzero.com/tutoriel-3-307309-le-systeme-de-micro-paiement-flattr.html
-/// http://www.cyber-junk.de/wp-content/cache/supercache/cyber-junk.de/entwickelt/flattr-button-im-eigenbau-mittels-curl-und-mini-api/index.html
-
 #include <unistd.h> // sleep, execl
 #include <signal.h>
 
@@ -60,12 +57,12 @@
 
 #include "config.h"
 #include "cairo-dock-icon-facility.h"  // cairo_dock_get_first_icon
-#include "cairo-dock-module-factory.h"
+#include "cairo-dock-module-manager.h"  // gldi_modules_new_from_directory
+#include "cairo-dock-module-instance-manager.h"  // GldiModuleInstance
 #include "cairo-dock-dock-manager.h"
-#include "cairo-dock-menu.h"
+#include "cairo-dock-desklet-manager.h"
 #include "cairo-dock-themes-manager.h"
-#include "cairo-dock-dialog-manager.h"
-#include "cairo-dock-notifications.h"
+#include "cairo-dock-dialog-factory.h"
 #include "cairo-dock-keyfile-utilities.h"
 #include "cairo-dock-config.h"
 #include "cairo-dock-file-manager.h"
@@ -73,12 +70,13 @@
 #include "cairo-dock-keybinder.h"
 #include "cairo-dock-opengl.h"
 #include "cairo-dock-packages.h"
-#include "cairo-dock-launcher-manager.h"  // cairo_dock_launch_command
+#include "cairo-dock-utils.h"  // cairo_dock_launch_command
 #include "cairo-dock-core.h"
 
 #include "cairo-dock-gui-manager.h"
 #include "cairo-dock-gui-backend.h"
 #include "cairo-dock-user-interaction.h"
+#include "cairo-dock-user-menu.h"
 
 //#define CAIRO_DOCK_THEME_SERVER "http://themes.glx-dock.org"
 #define CAIRO_DOCK_THEME_SERVER "http://download.tuxfamily.org/glxdock/themes"
@@ -100,7 +98,7 @@ extern CairoDockGLConfig g_openglConfig;
 extern gboolean g_bUseOpenGL;
 extern gboolean g_bEasterEggs;
 
-extern CairoDockModuleInstance *g_pCurrentModule;
+extern GldiModuleInstance *g_pCurrentModule;
 extern GtkWidget *cairo_dock_build_simple_gui_window (void);
 
 gboolean g_bForceCairo = FALSE;
@@ -114,6 +112,7 @@ static gint s_iGuiMode = 0;  // 0 = simple mode, 1 = advanced mode
 static gint s_iLastYear = 0;
 static gint s_iNbCrashes = 0;
 static gboolean s_bPingServer = TRUE;
+static gboolean s_bCDSessionLaunched = FALSE; // session CD already launched?
 
 
 static void _on_got_server_answer (const gchar *data, G_GNUC_UNUSED gpointer user_data)
@@ -131,7 +130,6 @@ static void _on_got_server_answer (const gchar *data, G_GNUC_UNUSED gpointer use
 static gboolean _cairo_dock_successful_launch (gpointer data)
 {
 	s_bSucessfulLaunch = TRUE;
-	
 	// new year greetings.
 	time_t t = time (NULL);
 	struct tm st;
@@ -146,10 +144,10 @@ static gboolean _cairo_dock_successful_launch (gpointer data)
 			G_TYPE_INVALID);
 		g_free (cConfFilePath);
 		
-		Icon *pIcon = cairo_dock_get_dialogless_icon ();
+		Icon *pIcon = gldi_icons_get_any_without_dialog ();
 		gchar *cMessage = g_strdup_printf (_("Happy new year %d !!!"), s_iLastYear);
 		gchar *cMessageFull = g_strdup_printf ("\n%s :-)\n", cMessage);
-		cairo_dock_show_temporary_dialog_with_icon (cMessageFull, pIcon, CAIRO_CONTAINER (g_pMainDock), 15000., CAIRO_DOCK_SHARE_DATA_DIR"/icons/balloons.png");
+		gldi_dialog_show_temporary_with_icon (cMessageFull, pIcon, CAIRO_CONTAINER (g_pMainDock), 15000., CAIRO_DOCK_SHARE_DATA_DIR"/icons/balloons.png");
 		g_free (cMessageFull);
 		g_free (cMessage);
 	}
@@ -218,7 +216,6 @@ static void _cairo_dock_set_signal_interception (void)
 	signal (SIGFPE, _cairo_dock_intercept_signal);  // Floating-point exception
 	signal (SIGILL, _cairo_dock_intercept_signal);  // Illegal instruction
 	signal (SIGABRT, _cairo_dock_intercept_signal);  // Abort // kill -6
-	signal (SIGTERM, _cairo_dock_quit);  // Term // kill -15 (system)
 }
 
 static gboolean on_delete_maintenance_gui (G_GNUC_UNUSED GtkWidget *pWidget, GMainLoop *pBlockingLoop)
@@ -247,10 +244,10 @@ static void _cairo_dock_get_global_config (const gchar *cCairoDockDataDir)
 			g_free (s_cDefaulBackend);
 			s_cDefaulBackend = NULL;
 		}
-		
 		s_iGuiMode = g_key_file_get_integer (pKeyFile, "Gui", "mode", NULL);  // 0 by default
 		s_iLastYear = g_key_file_get_integer (pKeyFile, "Launch", "last year", NULL);  // 0 by default
 		s_bPingServer = g_key_file_get_boolean (pKeyFile, "Launch", "ping server", NULL);  // FALSE by default
+		s_bCDSessionLaunched = g_key_file_get_boolean (pKeyFile, "Launch", "cd session", NULL);  // FALSE by default
 	}
 	else  // first launch or old version, the file doesn't exist yet.
 	{
@@ -522,7 +519,7 @@ int main (int argc, char** argv)
 		cairo_dock_fm_force_desktop_env (iDesktopEnv);
 	
 	if (bToggleIndirectRendering)
-		cairo_dock_force_indirect_rendering ();
+		gldi_gl_backend_force_indirect_rendering ();
 	
 	gchar *cExtraDirPath = g_strconcat (cRootDataDirPath, "/"CAIRO_DOCK_EXTRAS_DIR, NULL);
 	gchar *cThemesDirPath = g_strconcat (cRootDataDirPath, "/"CAIRO_DOCK_THEMES_DIR, NULL);
@@ -531,28 +528,24 @@ int main (int argc, char** argv)
 	cairo_dock_set_paths (cRootDataDirPath, cExtraDirPath, cThemesDirPath, cCurrentThemeDirPath, (gchar*)CAIRO_DOCK_SHARE_THEMES_DIR, (gchar*)CAIRO_DOCK_DISTANT_THEMES_DIR, cThemeServerAdress ? cThemeServerAdress : g_strdup (CAIRO_DOCK_THEME_SERVER));
 	
 	//\___________________ Check that OpenGL is safely usable, if not ask the user what to do.
-	if (bAskBackend || (g_bUseOpenGL && ! bForceOpenGL && ! bToggleIndirectRendering && ! cairo_dock_opengl_is_safe ()))  // opengl disponible sans l'avoir force mais pas safe => on demande confirmation.
+	if (bAskBackend || (g_bUseOpenGL && ! bForceOpenGL && ! bToggleIndirectRendering && ! gldi_gl_backend_is_safe ()))  // opengl disponible sans l'avoir force mais pas safe => on demande confirmation.
 	{
 		if (s_cDefaulBackend == NULL)  // pas de backend par defaut defini.
 		{
 			GtkWidget *dialog = gtk_dialog_new_with_buttons (_("Use OpenGL in Cairo-Dock"),
 				NULL,
 				GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-				GTK_STOCK_YES,
+				_("Yes"),
 				GTK_RESPONSE_YES,
-				GTK_STOCK_NO,
+				_("No"),
 				GTK_RESPONSE_NO,
 				NULL);
 			GtkWidget *label = gtk_label_new (_("OpenGL allows you to use the hardware acceleration, reducing the CPU load to the minimum.\nIt also allows some pretty visual effects similar to Compiz.\nHowever, some cards and/or their drivers don't fully support it, which may prevent the dock from running correctly.\nDo you want to activate OpenGL ?\n (To not show this dialog, launch the dock from the Application menu,\n  or with the -o option to force OpenGL and -c to force cairo.)"));
-			#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION >= 14)
-				GtkWidget *pContentBox = gtk_dialog_get_content_area (GTK_DIALOG(dialog));
-			#else
-				GtkWidget *pContentBox =  GTK_DIALOG(dialog)->vbox;
-			#endif
+			GtkWidget *pContentBox = gtk_dialog_get_content_area (GTK_DIALOG(dialog));
 
 			gtk_box_pack_start (GTK_BOX (pContentBox), label, FALSE, FALSE, 0);
 
-			GtkWidget *pAskBox = _gtk_hbox_new (3);
+			GtkWidget *pAskBox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 3);
 			gtk_box_pack_start (GTK_BOX (pContentBox), pAskBox, FALSE, FALSE, 0);
 			label = gtk_label_new (_("Remember this choice"));
 			GtkWidget *pCheckBox = gtk_check_button_new ();
@@ -566,7 +559,7 @@ int main (int argc, char** argv)
 			gtk_widget_destroy (dialog);
 			if (iAnswer == GTK_RESPONSE_NO)
 			{
-				cairo_dock_deactivate_opengl ();
+				gldi_gl_backend_deactivate ();
 			}
 			
 			if (bRememberChoice)  // l'utilisateur a defini le choix par defaut.
@@ -581,7 +574,7 @@ int main (int argc, char** argv)
 		}
 		else if (strcmp (s_cDefaulBackend, "opengl") != 0)  // un backend par defaut qui n'est pas OpenGL.
 		{
-			cairo_dock_deactivate_opengl ();
+			gldi_gl_backend_deactivate ();
 		}
 	}
 	g_print ("\n"
@@ -599,7 +592,7 @@ int main (int argc, char** argv)
 	//\___________________ load plug-ins (must be done after everything is initialized).
 	if (! bSafeMode)
 	{
-		cairo_dock_load_modules_in_directory (NULL, &erreur);  // load gldi-based plug-ins
+		gldi_modules_new_from_directory (NULL, &erreur);  // load gldi-based plug-ins
 		if (erreur != NULL)
 		{
 			cd_warning ("%s\n  no module will be available", erreur->message);
@@ -609,7 +602,7 @@ int main (int argc, char** argv)
 		
 		if (cUserDefinedModuleDir != NULL)
 		{
-			cairo_dock_load_modules_in_directory (cUserDefinedModuleDir, &erreur);  // load user plug-ins
+			gldi_modules_new_from_directory (cUserDefinedModuleDir, &erreur);  // load user plug-ins
 			if (erreur != NULL)
 			{
 				cd_warning ("%s\n  no additionnal module will be available", erreur->message);
@@ -625,87 +618,91 @@ int main (int argc, char** argv)
 	cairo_dock_load_user_gui_backend (s_iGuiMode);
 	
 	//\___________________ register to the useful notifications.
-	cairo_dock_register_notification_on_object (&myContainersMgr,
+	gldi_object_register_notification (&myContainerObjectMgr,
 		NOTIFICATION_DROP_DATA,
-		(CairoDockNotificationFunc) cairo_dock_notification_drop_data,
-		CAIRO_DOCK_RUN_AFTER, NULL);
-	cairo_dock_register_notification_on_object (&myContainersMgr,
+		(GldiNotificationFunc) cairo_dock_notification_drop_data,
+		GLDI_RUN_AFTER, NULL);
+	gldi_object_register_notification (&myContainerObjectMgr,
 		NOTIFICATION_CLICK_ICON,
-		(CairoDockNotificationFunc) cairo_dock_notification_click_icon,
-		CAIRO_DOCK_RUN_AFTER, NULL);
-	cairo_dock_register_notification_on_object (&myContainersMgr,
+		(GldiNotificationFunc) cairo_dock_notification_click_icon,
+		GLDI_RUN_AFTER, NULL);
+	gldi_object_register_notification (&myContainerObjectMgr,
 		NOTIFICATION_MIDDLE_CLICK_ICON,
-		(CairoDockNotificationFunc) cairo_dock_notification_middle_click_icon,
-		CAIRO_DOCK_RUN_AFTER, NULL);
-	cairo_dock_register_notification_on_object (&myContainersMgr,
+		(GldiNotificationFunc) cairo_dock_notification_middle_click_icon,
+		GLDI_RUN_AFTER, NULL);
+	gldi_object_register_notification (&myContainerObjectMgr,
 		NOTIFICATION_SCROLL_ICON,
-		(CairoDockNotificationFunc) cairo_dock_notification_scroll_icon,
-		CAIRO_DOCK_RUN_AFTER, NULL);
-	cairo_dock_register_notification_on_object (&myContainersMgr,
+		(GldiNotificationFunc) cairo_dock_notification_scroll_icon,
+		GLDI_RUN_AFTER, NULL);
+	gldi_object_register_notification (&myContainerObjectMgr,
 		NOTIFICATION_BUILD_CONTAINER_MENU,
-		(CairoDockNotificationFunc) cairo_dock_notification_build_container_menu,
-		CAIRO_DOCK_RUN_FIRST, NULL);
-	cairo_dock_register_notification_on_object (&myContainersMgr,
+		(GldiNotificationFunc) cairo_dock_notification_build_container_menu,
+		GLDI_RUN_FIRST, NULL);
+	gldi_object_register_notification (&myContainerObjectMgr,
 		NOTIFICATION_BUILD_ICON_MENU,
-		(CairoDockNotificationFunc) cairo_dock_notification_build_icon_menu,
-		CAIRO_DOCK_RUN_AFTER, NULL);
+		(GldiNotificationFunc) cairo_dock_notification_build_icon_menu,
+		GLDI_RUN_AFTER, NULL);
 	
-	cairo_dock_register_notification_on_object (&myDeskletsMgr,
+	gldi_object_register_notification (&myDeskletObjectMgr,
 		NOTIFICATION_CONFIGURE_DESKLET,
-		(CairoDockNotificationFunc) cairo_dock_notification_configure_desklet,
-		CAIRO_DOCK_RUN_AFTER, NULL);
-	cairo_dock_register_notification_on_object (&myDocksMgr,
+		(GldiNotificationFunc) cairo_dock_notification_configure_desklet,
+		GLDI_RUN_AFTER, NULL);
+	gldi_object_register_notification (&myDockObjectMgr,
 		NOTIFICATION_ICON_MOVED,
-		(CairoDockNotificationFunc) cairo_dock_notification_icon_moved,
-		CAIRO_DOCK_RUN_AFTER, NULL);
-	cairo_dock_register_notification_on_object (&myDocksMgr,
+		(GldiNotificationFunc) cairo_dock_notification_icon_moved,
+		GLDI_RUN_AFTER, NULL);
+	gldi_object_register_notification (&myDockObjectMgr,
 		NOTIFICATION_DESTROY,
-		(CairoDockNotificationFunc) cairo_dock_notification_dock_destroyed,
-		CAIRO_DOCK_RUN_AFTER, NULL);
-	cairo_dock_register_notification_on_object (&myModulesMgr,
+		(GldiNotificationFunc) cairo_dock_notification_dock_destroyed,
+		GLDI_RUN_AFTER, NULL);
+	gldi_object_register_notification (&myModuleObjectMgr,
 		NOTIFICATION_MODULE_ACTIVATED,
-		(CairoDockNotificationFunc) cairo_dock_notification_module_activated,
-		CAIRO_DOCK_RUN_AFTER, NULL);
-	cairo_dock_register_notification_on_object (&myModulesMgr,
+		(GldiNotificationFunc) cairo_dock_notification_module_activated,
+		GLDI_RUN_AFTER, NULL);
+	gldi_object_register_notification (&myModuleObjectMgr,
 		NOTIFICATION_MODULE_REGISTERED,
-		(CairoDockNotificationFunc) cairo_dock_notification_module_registered,
-		CAIRO_DOCK_RUN_AFTER, NULL);
-	cairo_dock_register_notification_on_object (&myModulesMgr,
+		(GldiNotificationFunc) cairo_dock_notification_module_registered,
+		GLDI_RUN_AFTER, NULL);
+	gldi_object_register_notification (&myModuleInstanceObjectMgr,
 		NOTIFICATION_MODULE_INSTANCE_DETACHED,
-		(CairoDockNotificationFunc) cairo_dock_notification_module_detached,
-		CAIRO_DOCK_RUN_AFTER, NULL);
-	cairo_dock_register_notification_on_object (&myDocksMgr,
+		(GldiNotificationFunc) cairo_dock_notification_module_detached,
+		GLDI_RUN_AFTER, NULL);
+	gldi_object_register_notification (&myDockObjectMgr,
 		NOTIFICATION_INSERT_ICON,
-		(CairoDockNotificationFunc) cairo_dock_notification_icon_inserted,
-		CAIRO_DOCK_RUN_AFTER, NULL);
-	cairo_dock_register_notification_on_object (&myDocksMgr,
+		(GldiNotificationFunc) cairo_dock_notification_icon_inserted,
+		GLDI_RUN_AFTER, NULL);
+	gldi_object_register_notification (&myDockObjectMgr,
 		NOTIFICATION_REMOVE_ICON,
-		(CairoDockNotificationFunc) cairo_dock_notification_icon_removed,
-		CAIRO_DOCK_RUN_AFTER, NULL);
-	cairo_dock_register_notification_on_object (&myDeskletsMgr,
+		(GldiNotificationFunc) cairo_dock_notification_icon_removed,
+		GLDI_RUN_AFTER, NULL);
+	gldi_object_register_notification (&myDeskletObjectMgr,
 		NOTIFICATION_DESTROY,
-		(CairoDockNotificationFunc) cairo_dock_notification_desklet_destroyed,
-		CAIRO_DOCK_RUN_AFTER, NULL);
-	cairo_dock_register_notification_on_object (&myDeskletsMgr,
-		NOTIFICATION_NEW_DESKLET,
-		(CairoDockNotificationFunc) cairo_dock_notification_desklet_destroyed,
-		CAIRO_DOCK_RUN_AFTER, NULL);
-	cairo_dock_register_notification_on_object (&myShortkeysMgr,
-		NOTIFICATION_SHORTKEY_ADDED,
-		(CairoDockNotificationFunc) cairo_dock_notification_shortkey_added_or_removed,
-		CAIRO_DOCK_RUN_AFTER, NULL);
-	cairo_dock_register_notification_on_object (&myShortkeysMgr,
-		NOTIFICATION_SHORTKEY_REMOVED,
-		(CairoDockNotificationFunc) cairo_dock_notification_shortkey_added_or_removed,
-		CAIRO_DOCK_RUN_AFTER, NULL);
-	cairo_dock_register_notification_on_object (&myShortkeysMgr,
+		(GldiNotificationFunc) cairo_dock_notification_desklet_added_removed,
+		GLDI_RUN_AFTER, NULL);
+	gldi_object_register_notification (&myDeskletObjectMgr,
+		NOTIFICATION_NEW,
+		(GldiNotificationFunc) cairo_dock_notification_desklet_added_removed,
+		GLDI_RUN_AFTER, NULL);
+	gldi_object_register_notification (&myShortkeyObjectMgr,
+		NOTIFICATION_NEW,
+		(GldiNotificationFunc) cairo_dock_notification_shortkey_added_removed_changed,
+		GLDI_RUN_AFTER, NULL);
+	gldi_object_register_notification (&myShortkeyObjectMgr,
+		NOTIFICATION_DESTROY,
+		(GldiNotificationFunc) cairo_dock_notification_shortkey_added_removed_changed,
+		GLDI_RUN_AFTER, NULL);
+	gldi_object_register_notification (&myShortkeyObjectMgr,
 		NOTIFICATION_SHORTKEY_CHANGED,
-		(CairoDockNotificationFunc) cairo_dock_notification_shortkey_added_or_removed,
-		CAIRO_DOCK_RUN_AFTER, NULL);
+		(GldiNotificationFunc) cairo_dock_notification_shortkey_added_removed_changed,
+		GLDI_RUN_AFTER, NULL);
 	
 	//\___________________ handle crashes.
 	if (! bTesting)
 		_cairo_dock_set_signal_interception ();
+	
+	//\___________________ handle terminate signals to quit properly (especially when the system shuts down).
+	signal (SIGTERM, _cairo_dock_quit);  // Term // kill -15 (system)
+	signal (SIGHUP,  _cairo_dock_quit);  // sent to a process when its controlling terminal is closed
 
 	//\___________________ Disable modules that have crashed
 	if (cExcludeModule != NULL && (s_iNbCrashes > 2 || bMaintenance)) // 3th crash or 4th (with -m)
@@ -748,13 +745,21 @@ int main (int argc, char** argv)
 	
 	//\___________________ load the current theme.
 	cd_message ("loading theme ...");
+	const gchar *cDesktopSessionEnv = g_getenv ("DESKTOP_SESSION");
 	if (! g_file_test (g_cConfFile, G_FILE_TEST_EXISTS))  // no theme yet, copy the default theme first.
 	{
-		const gchar *cDesktopSessionEnv = g_getenv ("DESKTOP_SESSION");
 		const gchar *cThemeName;
-		if (g_strcmp0 (cDesktopSessionEnv, "cairo-dock") == 0
-			|| g_strcmp0 (cDesktopSessionEnv, "cairo-dock-fallback") == 0)
+		if (g_strcmp0 (cDesktopSessionEnv, "cairo-dock") == 0)
+		{
 			cThemeName = "Default-Panel";
+			// We're using the CD session for the first time
+			s_bCDSessionLaunched = TRUE;
+			gchar *cConfFilePath = g_strdup_printf ("%s/.cairo-dock", g_cCairoDockDataDir);
+			cairo_dock_update_conf_file (cConfFilePath,
+				G_TYPE_BOOLEAN, "Launch", "cd session", s_bCDSessionLaunched,
+				G_TYPE_INVALID);
+			g_free (cConfFilePath);
+		}
 		else
 			cThemeName = "Default-Single";
 		gchar *cCommand = g_strdup_printf ("/bin/cp -r \"%s/%s\"/* \"%s\"", CAIRO_DOCK_SHARE_DATA_DIR"/themes", cThemeName, g_cCurrentThemePath);
@@ -764,6 +769,55 @@ int main (int argc, char** argv)
 			cd_warning ("Not able to launch this command: %s", cCommand);
 		g_free (cCommand);
 	}
+	/* The first time the Cairo-Dock session is used but not the first time the
+	 *  dock is launched: propose to use the Default-Panel theme if a second
+	 *  dock is not used (case: the user has already launched the dock and he
+	 *  wants to test the Cairo-Dock session: propose a theme with two docks)
+	 */
+	else if (! s_bCDSessionLaunched && g_strcmp0 (cDesktopSessionEnv, "cairo-dock") == 0)
+	{
+		gchar *cSecondDock = g_strdup_printf ("%s/"CAIRO_DOCK_MAIN_DOCK_NAME"-2.conf", g_cCurrentThemePath);
+		if (! g_file_test (cSecondDock, G_FILE_TEST_EXISTS))
+		{
+			GtkWidget *pDialog = gtk_dialog_new_with_buttons (_("You're using our Cairo-Dock session"),
+				NULL,
+				GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+				_("Yes"), GTK_RESPONSE_YES,
+				_("No"), GTK_RESPONSE_NO,
+				NULL);
+			GtkWidget *pLabel = gtk_label_new (_("It can be interesting to use an adapted theme for this session.\n\nDo you want to load our \"Default-Panel\" theme?\n\nNote: your current theme will be saved and can be reimported later from the Themes manager"));
+
+			GtkWidget *pContentBox = gtk_dialog_get_content_area (GTK_DIALOG (pDialog));
+			gtk_box_pack_start (GTK_BOX (pContentBox), pLabel, FALSE, FALSE, 0);
+			gtk_widget_show_all (pDialog);
+
+			gint iAnswer = gtk_dialog_run (GTK_DIALOG (pDialog)); // will block the main loop
+			gtk_widget_destroy (pDialog);
+			if (iAnswer == GTK_RESPONSE_YES)
+			{
+				time_t epoch = (time_t) time (NULL);
+				struct tm currentTime;
+				localtime_r (&epoch, &currentTime);
+				char cDateBuffer[22+1];
+				strftime (cDateBuffer, 22, "Theme_%Y%m%d_%H%M%S", &currentTime);
+
+				cairo_dock_export_current_theme (cDateBuffer, TRUE, TRUE);
+				cairo_dock_import_theme ("Default-Panel", TRUE, TRUE);
+			}
+
+			// Force init script
+			g_timeout_add_seconds (4, _cairo_dock_first_launch_setup, NULL);
+		}
+		g_free (cSecondDock);
+
+		// Update 'cd session' key: we already check that the user is using an adapted theme for this session
+		s_bCDSessionLaunched = TRUE;
+		gchar *cConfFilePath = g_strdup_printf ("%s/.cairo-dock", g_cCairoDockDataDir);
+		cairo_dock_update_conf_file (cConfFilePath,
+			G_TYPE_BOOLEAN, "Launch", "cd session", s_bCDSessionLaunched,
+			G_TYPE_INVALID);
+		g_free (cConfFilePath);
+	}
 	cairo_dock_load_current_theme ();
 	
 	//\___________________ lock mode.
@@ -773,11 +827,10 @@ int main (int argc, char** argv)
 		myDocksParam.bLockAll = TRUE;
 	}
 	
-	if (!bSafeMode && cairo_dock_get_nb_modules () <= 1)  // 1 en comptant l'aide
+	if (!bSafeMode && gldi_module_get_nb () <= 1)  // 1 en comptant l'aide
 	{
-		Icon *pIcon = cairo_dock_get_dialogless_icon ();
-		///cairo_dock_ask_question_and_wait (_("No plug-in were found.\nPlug-ins provide most of the functionalities of Cairo-Dock (animations, applets, views, etc).\nSee http://glx-dock.org for more information.\nSince there is almost no meaning in running the dock without them, the application will quit now."), pIcon, CAIRO_CONTAINER (g_pMainDock));
-		cairo_dock_show_temporary_dialog_with_icon (_("No plug-in were found.\nPlug-ins provide most of the functionalities (animations, applets, views, etc).\nSee http://glx-dock.org for more information.\nThere is almost no meaning in running the dock without them and it's probably due to a problem with the installation of these plug-ins.\nBut if you really want to use the dock without these plug-ins, you can launch the dock with the '-f' option to no longer have this message.\n"), pIcon, CAIRO_CONTAINER (g_pMainDock), 0., CAIRO_DOCK_SHARE_DATA_DIR"/"CAIRO_DOCK_ICON);
+		Icon *pIcon = gldi_icons_get_any_without_dialog ();
+		gldi_dialog_show_temporary_with_icon (_("No plug-in were found.\nPlug-ins provide most of the functionalities (animations, applets, views, etc).\nSee http://glx-dock.org for more information.\nThere is almost no meaning in running the dock without them and it's probably due to a problem with the installation of these plug-ins.\nBut if you really want to use the dock without these plug-ins, you can launch the dock with the '-f' option to no longer have this message.\n"), pIcon, CAIRO_CONTAINER (g_pMainDock), 0., CAIRO_DOCK_SHARE_DATA_DIR"/"CAIRO_DOCK_ICON);
 	}
 	
 	//\___________________ display the changelog in case of a new version.
@@ -789,57 +842,8 @@ int main (int argc, char** argv)
 			G_TYPE_STRING, "Launch", "last version", CAIRO_DOCK_VERSION,
 			G_TYPE_INVALID);
 		g_free (cConfFilePath);
-		
-		if (strcmp (CAIRO_DOCK_VERSION, "3.2.1") == 0)
-		{
-			// from 3.2, Indicator-generic replaces all the indicator applets, and is very helpful if we are on a cairo-dock session.
-			if (g_strcmp0 (g_getenv ("DESKTOP_SESSION"), "cairo-dock") == 0)
-			{
-				const gchar *cModuleName = "Indicator-Generic";
-				CairoDockModule *pModule = cairo_dock_find_module_from_name (cModuleName);
-				if (pModule && pModule->pInstancesList == NULL) // it exists but it's not activated
-				{
-					/* copy the .conf file mostly to place the new icons on the
-					 * right place (at least on the second dock) but only if we are
-					 * using a second dock
-					 */
-					gchar *cSecondDockFile = g_strdup_printf ("%s/_MainDock_-2.conf", g_cCurrentThemePath);
-					if (g_file_test (cSecondDockFile, G_FILE_TEST_EXISTS))
-					{
-						gchar *cCommand = g_strdup_printf ("cp -r \"%s/%s\" \"%s/plug-ins/\"",
-							CAIRO_DOCK_SHARE_DATA_DIR"/themes/Default-Panel/plug-ins",
-							cModuleName,
-							g_cCurrentThemePath);
 
-						int r = system (cCommand);
-						if (r < 0)
-							cd_warning ("Not able to launch this command: %s", cCommand);
-						g_free (cCommand);
-					}
-					g_free (cSecondDockFile);
-
-					cd_warning ("Indicator-Generic now replaces Print-Menu and Sync-Menu, activate it automatically");
-					cairo_dock_activate_module_and_load (cModuleName); // launch it right now
-				}
-			}
-			
-			// Switch from "Show a window's thumbnail" to "Make the icon transparent" by default due to the bug #1127281
-			GKeyFile *pKeyFile = cairo_dock_open_key_file (g_cConfFile);
-			if (pKeyFile)
-			{
-				gint iMinimizedWindowRenderType = g_key_file_get_integer (pKeyFile, "TaskBar", "minimized", NULL);
-				if (iMinimizedWindowRenderType == 1)  // "Show a window's thumbnail" is not well supported on all cards because of 'XCompositeRedirectWindow', and can provoke visual artefacts when srolling :-/
-				{
-					cd_warning ("Switch from 'Show a window's thumbnail' to 'Make the icon transparent' option due to a very annoying bug that we can have with some video cards. This bug seems to be fixed when using recent video drivers and this option can be re-enabled from the config panel.");
-					g_key_file_set_integer (pKeyFile, "TaskBar", "minimized", 0);
-					cairo_dock_write_keys_to_file (pKeyFile, g_cConfFile);
-					
-					GldiManager *pManager = gldi_get_manager ("Taskbar");
-					gldi_reload_manager_from_keyfile (pManager, pKeyFile);
-				}
-				g_key_file_free (pKeyFile);
-			}
-		}
+		/// If any operation must be done on the user theme (like activating a module by default, or disabling an option), it should be done here once (when CAIRO_DOCK_VERSION matches the new version).
 	}
 	
 	//g_print ("bFirstLaunch: %d; bNewVersion: %d\n", bFirstLaunch, bNewVersion);
@@ -847,26 +851,48 @@ int main (int argc, char** argv)
 	{
 		g_timeout_add_seconds (4, _cairo_dock_first_launch_setup, NULL);
 	}
-	else if (bNewVersion)  // nouvelle version -> changelog (si c'est le 1er lancement, inutile de dire ce qui est nouveau, et de plus on a deja le message de bienvenue).
+	else if (bNewVersion)  // new version -> changelog (if it's the first launch, useless to display what's new, we already have the Welcome message).
 	{
 		gchar *cChangeLogFilePath = g_strdup_printf ("%s/ChangeLog.txt", CAIRO_DOCK_SHARE_DATA_DIR);
 		GKeyFile *pKeyFile = cairo_dock_open_key_file (cChangeLogFilePath);
 		if (pKeyFile != NULL)
 		{
-			gchar *cKeyName = g_strdup_printf ("%d.%d.%d", g_iMajorVersion, g_iMinorVersion, g_iMicroVersion);  // version sans les "alpha", "beta", "rc", etc.
+			gchar *cKeyName = g_strdup_printf ("%d.%d.%d", g_iMajorVersion, g_iMinorVersion, g_iMicroVersion);  // version without "alpha", "beta", "rc", etc.
 			gchar *cChangeLogMessage = g_key_file_get_string (pKeyFile, "ChangeLog", cKeyName, NULL);
 			g_free (cKeyName);
 			if (cChangeLogMessage != NULL)
 			{
+				GString *sChangeLogMessage = g_string_new (gettext (cChangeLogMessage));
+				g_free (cChangeLogMessage);
+
+				// changelog message is now split (by line): to not re-translate all the message when there is a modification
+				int i = 0;
+				while (TRUE)
+				{
+					cKeyName = g_strdup_printf ("%d.%d.%d.%d", g_iMajorVersion, g_iMinorVersion, g_iMicroVersion, i);
+					cChangeLogMessage = g_key_file_get_string (pKeyFile, "ChangeLog", cKeyName, NULL);
+					g_free (cKeyName);
+
+					if (cChangeLogMessage == NULL) // no more message
+						break;
+
+					g_string_append_printf (sChangeLogMessage, "\n %s", gettext (cChangeLogMessage));
+
+					g_free (cChangeLogMessage);
+					i++;
+				}
+
 				Icon *pFirstIcon = cairo_dock_get_first_icon (g_pMainDock->icons);
 				
-				CairoDialogAttribute attr;
-				memset (&attr, 0, sizeof (CairoDialogAttribute));
-				attr.cText = gettext (cChangeLogMessage);
+				CairoDialogAttr attr;
+				memset (&attr, 0, sizeof (CairoDialogAttr));
+				attr.cText = sChangeLogMessage->str;
 				attr.cImageFilePath = CAIRO_DOCK_SHARE_DATA_DIR"/"CAIRO_DOCK_ICON;
 				attr.bUseMarkup = TRUE;
-				cairo_dock_build_dialog (&attr, pFirstIcon, CAIRO_CONTAINER (g_pMainDock));
-				g_free (cChangeLogMessage);
+				attr.pIcon = pFirstIcon;
+				attr.pContainer = CAIRO_CONTAINER (g_pMainDock);
+				gldi_dialog_new (&attr);
+				g_string_free (sChangeLogMessage, TRUE);
 			}
 			g_key_file_free (pKeyFile);
 		}
@@ -881,17 +907,16 @@ int main (int argc, char** argv)
 		else // since the 3th crash: the applet has been disabled
 			cMessage = g_strdup_printf (_("The module '%s' has been deactivated because it may have caused some problems.\nYou can reactivate it, if it happens again thanks to report it at http://glx-dock.org"), cExcludeModule);
 		
-		CairoDockModule *pModule = cairo_dock_find_module_from_name (cExcludeModule);
-		Icon *icon = cairo_dock_get_dialogless_icon ();
-		cairo_dock_show_temporary_dialog_with_icon (cMessage, icon, CAIRO_CONTAINER (g_pMainDock), 15000., (pModule ? pModule->pVisitCard->cIconFilePath : NULL));
+		GldiModule *pModule = gldi_module_get (cExcludeModule);
+		Icon *icon = gldi_icons_get_any_without_dialog ();
+		gldi_dialog_show_temporary_with_icon (cMessage, icon, CAIRO_CONTAINER (g_pMainDock), 15000., (pModule ? pModule->pVisitCard->cIconFilePath : NULL));
 		g_free (cMessage);
 	}
 	
 	if (! bTesting)
 		g_timeout_add_seconds (5, _cairo_dock_successful_launch, GINT_TO_POINTER (bFirstLaunch));
-	
-	// TODO list in the 'TODO' file ;)
-	
+
+	// Start Mainloop
 	gtk_main ();
 	
 	signal (SIGSEGV, NULL);  // Segmentation violation
@@ -899,6 +924,8 @@ int main (int argc, char** argv)
 	signal (SIGILL, NULL);  // Illegal instruction
 	signal (SIGABRT, NULL);
 	signal (SIGTERM, NULL);
+	signal (SIGHUP, NULL);
+
 	gldi_free_all ();
 
 	#if (LIBRSVG_MAJOR_VERSION == 2 && LIBRSVG_MINOR_VERSION < 36)
