@@ -24,7 +24,7 @@
 #include <glib.h>
 
 #include "cairo-dock-struct.h"
-#include "cairo-dock-desktop-file-factory.h"
+#include "cairo-dock-style-facility.h"  // GldiColor
 #include "cairo-dock-image-buffer.h"
 #include "cairo-dock-icon-factory.h"
 #include "cairo-dock-container.h"
@@ -42,7 +42,6 @@ G_BEGIN_DECLS
 * A dock can be either a main-dock (not linked to any icon) or a sub-dock (linked to an icon of another dock), and there can be as many docks of each sort as you want.
 */
 
-
 typedef enum {
 	CAIRO_DOCK_BOTTOM = 0,
 	CAIRO_DOCK_TOP,
@@ -56,7 +55,7 @@ typedef enum {
 #define CAIRO_DOCK_INSERT_SEPARATOR TRUE
 
 typedef void (*CairoDockComputeSizeFunc) (CairoDock *pDock);
-typedef Icon * (*CairoDockCalculateIconsFunc) (CairoDock *pDock);
+typedef Icon* (*CairoDockCalculateIconsFunc) (CairoDock *pDock);
 typedef void (*CairoDockRenderFunc) (cairo_t *pCairoContext, CairoDock *pDock);
 typedef void (*CairoDockRenderOptimizedFunc) (cairo_t *pCairoContext, CairoDock *pDock, GdkRectangle *pArea);
 typedef void (*CairoDockSetSubDockPositionFunc) (Icon *pPointedIcon, CairoDock *pParentDock);
@@ -120,17 +119,29 @@ typedef enum {
 	CAIRO_DOCK_NB_VISI
 	} CairoDockVisibility;
 
+typedef struct _CairoDockAttr CairoDockAttr;
+struct _CairoDockAttr {
+	// parent attributes
+	GldiContainerAttr cattr;
+	const gchar *cDockName;
+	const gchar *cRendererName;
+	GList *pIconList;
+	gboolean bSubDock;
+	CairoDock *pParentDock;
+};
 
 /// Definition of a Dock, which derives from a Container.
 struct _CairoDock {
 	/// container.
-	CairoContainer container;
+	GldiContainer container;
 	/// the list of icons.
 	GList* icons;
 	/// Set to TRUE for the main dock (the first to be created, and the one containing the taskbar).
 	gboolean bIsMainDock;
 	/// number of icons pointing on the dock (0 means it is a root dock, >0 a sub-dock).
 	gint iRefCount;
+	/// unique name of the dock
+	gchar *cDockName;
 	
 	//\_______________ Config parameters.
 	// position
@@ -154,9 +165,9 @@ struct _CairoDock {
 	/// whether to repeat the image as a pattern, or to stretch it to fill the dock.
 	gboolean bBgImageRepeat;
 	/// first color of the gradation
-	gdouble fBgColorBright[4];
+	GldiColor fBgColorBright;
 	/// second color of the gradation
-	gdouble fBgColorDark[4];
+	GldiColor fBgColorDark;
 	/// Background image buffer of the dock.
 	CairoDockImageBuffer backgroundBuffer;
 	gboolean bExtendedMode;
@@ -269,11 +280,11 @@ struct _CairoDock {
 	/// state of the input shape (active, at rest, hidden).
 	CairoDockInputState iInputState;
 	/// input shape of the window when the dock is at rest.
-	GldiShape* pShapeBitmap;
+	cairo_region_t* pShapeBitmap;
 	/// input shape of the window when the dock is hidden.
-	GldiShape* pHiddenShapeBitmap;
+	cairo_region_t* pHiddenShapeBitmap;
 	/// input shape of the window when the dock is active (NULL to cover all dock).
-	GldiShape* pActiveShapeBitmap;
+	cairo_region_t* pActiveShapeBitmap;
 	
 	//\_______________ OpenGL.
 	GLuint iRedirectedTexture;
@@ -283,104 +294,46 @@ struct _CairoDock {
 };
 
 
-/** Say if a Container is a Dock.
-* @param pContainer the container.
-* @return TRUE if the container is a Dock.
+/** Say if an object is a Dock.
+*@param obj the object.
+*@return TRUE if the object is a Dock.
 */
-#define CAIRO_DOCK_IS_DOCK(pContainer) (pContainer != NULL && ((CairoContainer*)pContainer)->iType == CAIRO_DOCK_TYPE_DOCK)
+#define GLDI_OBJECT_IS_DOCK(obj) gldi_object_is_manager_child (GLDI_OBJECT(obj), &myDockObjectMgr)
+#define CAIRO_DOCK_IS_DOCK GLDI_OBJECT_IS_DOCK
 
 /** Cast a Container into a Dock.
-* @param pDock the container to consider as a dock.
+* @param p the container to consider as a dock.
 * @return the dock.
 */
-#define CAIRO_DOCK(pDock) ((CairoDock *)pDock)
+#define CAIRO_DOCK(p) ((CairoDock *)p)
 
 
-CairoDock *cairo_dock_new_dock (void);
+void cairo_dock_freeze_docks (gboolean bFreeze);
 
-void cairo_dock_free_dock (CairoDock *pDock);
+void gldi_dock_init_internals (CairoDock *pDock);
 
-void cairo_dock_make_sub_dock (CairoDock *pDock, CairoDock *pParentDock, const gchar *cRendererName);
 
-/** Insert an icon into a dock.
-* Do nothing if the icon already exists inside the dock.
-* @param icon the icon to be inserted. It should have been filled beforehand.
-* @param pDock the dock to insert inside.
-* @param bAnimated TRUE to arm the icon's animation for insertion.
-* @param bInsertSeparator TRUE to insert an automatic separator if needed.
-* @param pCompareFunc a sorting function to place the new icon amongst the others, or NULL to sort by group/order.
+/** Create a new root dock.
+*@param cDockName the name that identifies the dock
+*@return the new dock.
 */
-void cairo_dock_insert_icon_in_dock_full (Icon *icon, CairoDock *pDock, gboolean bAnimated, gboolean bInsertSeparator, GCompareFunc pCompareFunc);
+CairoDock *gldi_dock_new (const gchar *cDockName);
 
-/** Insert an icon into a dock.
-* Insert an automatic separator if needed. Do nothing if the icon already exists inside the dock.
-* @param icon the icon to be inserted. It should have been filled beforehand.
-* @param pDock the dock to insert inside.
-* @param bAnimated TRUE to arm the icon's animation for insertion.
+/** Create a new dock of type "sub-dock", and load a given list of icons inside. The list then belongs to the dock, so it must not be freeed after that. The buffers of each icon are loaded, so they just need to have an image filename and a name.
+* @param cDockName the name that identifies the dock.
+* @param cRendererName name of a renderer. If NULL, the default renderer will be applied.
+* @param pParentDock the parent dock.
+* @param pIconList a list of icons that will be loaded and inserted into the new dock (optional).
+* @return the new dock.
 */
-#define cairo_dock_insert_icon_in_dock(icon, pDock, bAnimated) cairo_dock_insert_icon_in_dock_full (icon, pDock, bAnimated, TRUE, NULL)
+CairoDock *gldi_subdock_new (const gchar *cDockName, const gchar *cRendererName, CairoDock *pParentDock, GList *pIconList);
 
-/** Detach an icon from its dock. The icon is not destroyed, and can be directly re-inserted in another container; it keeps its sub-dock, but looses its dialogs. Do nothing if the icon doesn't exist inside the dock.
-*@param icon the icon to detach.
-*@param pDock the dock containing the icon.
-*@param bCheckUnusedSeparator TRUE to check and remove unnecessary separators.
-*@return TRUE if the icon has been detached.
-*/
-gboolean cairo_dock_detach_icon_from_dock_full (Icon *icon, CairoDock *pDock, gboolean bCheckUnusedSeparator);
-#define cairo_dock_detach_icon_from_dock(icon, pDock) cairo_dock_detach_icon_from_dock_full (icon, pDock, TRUE)
-
-void cairo_dock_remove_icon_from_dock_full (CairoDock *pDock, Icon *icon, gboolean bCheckUnusedSeparator);
-
-/** Completely remove an icon from the dock, that is to say detach the icon, and remove all links with Cairo-Dock : its .desktop is deleted, its module is deactivated, and its Xid is removed from the Taskbar (its class is handled too).
-* Unnecessary separators are not tested.
-* The icon is not yet destroyed, but looses its sub-dock in case of a container launcher.
-*@param pDock the dock containing the icon, or NULL if the icon is already detached.
-*@param icon the icon to be removed.
-*/
-#define cairo_dock_remove_one_icon_from_dock(pDock, icon) cairo_dock_remove_icon_from_dock_full (pDock, icon, FALSE)
-
-/** Completely remove an icon from the dock, that is to say detach the icon, and  remove all links with Cairo-Dock : its .desktop is deleted, its module is deactivated, and its Xid is removed from the Taskbar (its class is handled too).
-* Unnecessary separators are removed as well.
-* The icon is not yet destroyed, but looses its sub-dock in case of a container launcher.
-*@param pDock the dock containing the icon, or NULL if the icon is already detached.
-*@param icon the icon to be removed.
-*/
-#define cairo_dock_remove_icon_from_dock(pDock, icon) cairo_dock_remove_icon_from_dock_full (pDock, icon, TRUE)
-
-/** Remove and destroy all automatic separators inside a dock.
-*@param pDock the dock.
-*/
-void cairo_dock_remove_automatic_separators (CairoDock *pDock);
-
-/** Add automatic separators between the different groups of icons inside a dock.
-*@param pDock the dock.
-*/
-void cairo_dock_insert_automatic_separators_in_dock (CairoDock *pDock);
-
-Icon *cairo_dock_add_new_launcher_by_uri_or_type (const gchar *cExternDesktopFileURI, CairoDockDesktopFileType iType, CairoDock *pReceivingDock, double fOrder);
-
-/** Add a launcher from a common desktop file : create and add the corresponding .desktop file with the others, load the corresponding icon, and insert it inside a dock with an animtion.
-*@param cExternDesktopFileURI path to a desktop file.
-*@param pReceivingDock the dock that will hold the new launcher.
-*@param fOrder the order of the icon inside the dock.
-*@return the newly created Icon corresponding to the file, or NULL if an error occured.
-*/
-#define cairo_dock_add_new_launcher_by_uri(cExternDesktopFileURI, pReceivingDock, fOrder) cairo_dock_add_new_launcher_by_uri_or_type (cExternDesktopFileURI, CAIRO_DOCK_DESKTOP_FILE_FOR_LAUNCHER, pReceivingDock, fOrder)
-
-/** Add an empty default launcher of a given type : create and add the corresponding .desktop file with the others, load the corresponding icon, and insert it inside a dock with an animtion. The launcher is then suitable for being edited by the user to add real properties.
-*@param iType type of the launcher.
-*@param pReceivingDock the dock that will hold the new launcher.
-*@param fOrder the order of the icon inside the dock.
-*@return the newly created Icon corresponding to the type, or NULL if an error occured.
-*/
-#define cairo_dock_add_new_launcher_by_type(iType, pReceivingDock, fOrder) cairo_dock_add_new_launcher_by_uri_or_type (NULL, iType, pReceivingDock, fOrder)
 
 /** Remove all icons from a dock (and its sub-docks). If the receiving dock is NULL, the icons are destroyed and removed from the current theme itself.
 *@param pDock a dock.
 *@param pReceivingDock the dock that will receive the icons, or NULL to destroy and remove the icons.
-*@param cReceivingDockName name of the receiving dock.
 */
-void cairo_dock_remove_icons_from_dock (CairoDock *pDock, CairoDock *pReceivingDock, const gchar *cReceivingDockName);
+void cairo_dock_remove_icons_from_dock (CairoDock *pDock, CairoDock *pReceivingDock);
 
 void cairo_dock_reload_buffers_in_dock (CairoDock *pDock, gboolean bRecursive, gboolean bUpdateIconSize);
 
