@@ -17,29 +17,31 @@
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include <string.h>
-#include <sys/stat.h>
+#include <stdlib.h>      // atoi
+#include <string.h>      // memset
+#include <sys/stat.h>    // stat
+#include <fcntl.h>  // open
+#include <sys/sendfile.h>  // sendfile
+#include <errno.h>  // errno
 
-#include "cairo-dock-notifications.h"
+#include "gldi-config.h"
 #include "cairo-dock-dock-factory.h"
 #include "cairo-dock-dock-facility.h"
 #include "cairo-dock-desklet-factory.h"  // cairo_dock_fm_create_icon_from_URI
 #include "cairo-dock-icon-factory.h"
 #include "cairo-dock-image-buffer.h"
 #include "cairo-dock-draw.h"
-#include "cairo-dock-dialog-manager.h"
+#include "cairo-dock-dialog-factory.h"  // gldi_dialog_show_temporary
 #include "cairo-dock-log.h"
 #include "cairo-dock-dock-manager.h"
-#include "cairo-dock-desktop-file-factory.h"
 #include "cairo-dock-container.h"
-#include "cairo-dock-launcher-manager.h"  // cairo_dock_launch_command_syncl
-#include "cairo-dock-X-utilities.h"  // cairo_dock_property_is_present_on_root
+#include "cairo-dock-utils.h"  // cairo_dock_launch_command_sync, cairo_dock_property_is_present_on_root
 #include "cairo-dock-icon-manager.h"  // cairo_dock_free_icon
 #define _MANAGER_DEF_
 #include "cairo-dock-file-manager.h"
 
 // public (manager, config, data)
-CairoDesktopEnvManager myDesktopEnvMgr;
+GldiManager myDesktopEnvMgr;
 CairoDockDesktopEnv g_iDesktopEnv = CAIRO_DOCK_UNKNOWN_ENV;
 
 // dependancies
@@ -403,7 +405,7 @@ gboolean cairo_dock_fm_show_system_monitor (void)
 		return FALSE;
 }
 
-Icon *cairo_dock_fm_create_icon_from_URI (const gchar *cURI, CairoContainer *pContainer, CairoDockFMSortType iFileSortType)
+Icon *cairo_dock_fm_create_icon_from_URI (const gchar *cURI, GldiContainer *pContainer, CairoDockFMSortType iFileSortType)
 {
 	if (s_pEnvBackend == NULL || s_pEnvBackend->get_file_info == NULL)
 		return NULL;
@@ -413,7 +415,7 @@ Icon *cairo_dock_fm_create_icon_from_URI (const gchar *cURI, CairoContainer *pCo
 	s_pEnvBackend->get_file_info (cURI, &pNewIcon->cName, &pNewIcon->cCommand, &pNewIcon->cFileName, &bIsDirectory, &pNewIcon->iVolumeID, &pNewIcon->fOrder, iFileSortType);
 	if (pNewIcon->cName == NULL)
 	{
-		cairo_dock_free_icon (pNewIcon);
+		gldi_object_unref (GLDI_OBJECT (pNewIcon));
 		return NULL;
 	}
 	if (bIsDirectory)
@@ -451,7 +453,7 @@ Icon *cairo_dock_fm_create_icon_from_URI (const gchar *cURI, CairoContainer *pCo
 }
 
 
-gboolean cairo_dock_fm_move_into_directory (const gchar *cURI, Icon *icon, CairoContainer *pContainer)
+gboolean cairo_dock_fm_move_into_directory (const gchar *cURI, Icon *icon, GldiContainer *pContainer)
 {
 	g_return_val_if_fail (cURI != NULL && icon != NULL, FALSE);
 	cd_message (" -> copie de %s dans %s", cURI, icon->cBaseURI);
@@ -460,7 +462,7 @@ gboolean cairo_dock_fm_move_into_directory (const gchar *cURI, Icon *icon, Cairo
 	{
 		cd_warning ("couldn't copy this file.\nCheck that you have writing rights, and that the new does not already exist.");
 		gchar *cMessage = g_strdup_printf ("Warning : couldn't copy %s into %s.\nCheck that you have writing rights, and that the name does not already exist.", cURI, icon->cBaseURI);
-		cairo_dock_show_temporary_dialog (cMessage, icon, pContainer, 4000);
+		gldi_dialog_show_temporary (cMessage, icon, pContainer, 4000);
 		g_free (cMessage);
 	}
 	return bSuccess;
@@ -483,40 +485,127 @@ int cairo_dock_get_file_size (const gchar *cFilePath)
 
 gboolean cairo_dock_copy_file (const gchar *cFilePath, const gchar *cDestPath)
 {
-	GError *error = NULL;
-	gchar *cContent = NULL;
-	gsize length = 0;
-	g_file_get_contents (cFilePath,
-		&cContent,
-		&length,
-		&error);
-	if (error != NULL)
+	gboolean ret = TRUE;
+	// open both files
+	int src_fd = open (cFilePath, O_RDONLY);
+	int dest_fd = open (cDestPath, O_CREAT | O_WRONLY, S_IRUSR|S_IWUSR | S_IRGRP | S_IROTH);  // mode=644
+	struct stat stat;
+	// get data size to be copied
+	if (fstat (src_fd, &stat) < 0)
 	{
-		cd_warning ("couldn't copy file '%s' (%s)", cFilePath, error->message);
-		g_error_free (error);
+		cd_warning ("couldn't get info of file '%s' (%s)", cFilePath, strerror(errno));
+		ret = FALSE;
+	}
+	else
+	{
+		// perform in-kernel transfer (zero copy to user space)
+		int size;
+		#ifdef __FreeBSD__
+		size = sendfile (src_fd, dest_fd, 0, stat.st_size, NULL, NULL, 0);
+		#else  // Linux >= 2.6.33 for being able to have a regular file as the output socket
+		size = sendfile (dest_fd, src_fd, NULL, stat.st_size);  // note the inversion between both calls ^_^;
+		#endif
+		if (size < 0)  // error, fallback to a read-write method
+		{
+			cd_debug ("couldn't fast-copy file '%s' to '%s' (%s)", cFilePath, cDestPath, strerror(errno));
+			// read data
+			char *buf = g_new (char, stat.st_size);
+			size = read (src_fd, buf, stat.st_size);
+			if (size < 0)
+			{
+				cd_warning ("couldn't read file '%s' (%s)", cFilePath, strerror(errno));
+				ret = FALSE;
+			}
+			else
+			{
+				// copy data
+				size = write (dest_fd, buf, stat.st_size);
+				if (size < 0)
+				{
+					cd_warning ("couldn't write to file '%s' (%s)", cDestPath, strerror(errno));
+					ret = FALSE;
+				}
+			}
+			g_free (buf);
+		}
+	}
+	close (dest_fd);
+	close (src_fd);
+	return ret;
+}
+
+
+  ///////////
+ /// PID ///
+///////////
+
+int cairo_dock_fm_get_pid (const gchar *cProcessName)
+{
+	int iPID = -1;
+	gchar *cCommand = g_strdup_printf ("pidof %s", cProcessName);
+	gchar *cPID = cairo_dock_launch_command_sync (cCommand);
+
+	if (cPID != NULL && *cPID != '\0')
+		iPID = atoi (cPID);
+
+	g_free (cPID);
+	g_free (cCommand);
+
+	return iPID;
+}
+
+static gboolean _wait_pid (gpointer *pData)
+{
+	gboolean bCheckSameProcess = GPOINTER_TO_INT (pData[0]);
+	gchar *cProcess = pData[1];
+
+	// check if /proc/%d dir exists or the process is running
+	if ((bCheckSameProcess && ! g_file_test (cProcess, G_FILE_TEST_EXISTS))
+		|| (! bCheckSameProcess && cairo_dock_fm_get_pid (cProcess) == -1))
+	{
+		GSourceFunc pCallback = pData[2];
+		gpointer pUserData = pData[3];
+
+		pCallback (pUserData);
+
+		// free allocated ressources just used for this function
+		g_free (cProcess);
+		g_free (pData);
+
 		return FALSE;
 	}
-	
-	gchar *cDestFilePath = NULL;
-	if (g_file_test (cDestPath, G_FILE_TEST_IS_DIR))
+
+	return TRUE;
+}
+
+gboolean cairo_dock_fm_monitor_pid (const gchar *cProcessName, gboolean bCheckSameProcess, GSourceFunc pCallback, gboolean bAlwaysLaunch, gpointer pUserData)
+{
+	int iPID = cairo_dock_fm_get_pid (cProcessName);
+	if (iPID == -1)
 	{
-		gchar *cFileName = g_path_get_basename (cFilePath);
-		cDestFilePath = g_strdup_printf ("%s/%s", cDestPath, cFileName);
-		g_free (cFileName);
-	}
-	
-	g_file_set_contents (cDestFilePath?cDestFilePath:cDestPath,
-		cContent,
-		length,
-		&error);
-	g_free (cDestFilePath);
-	g_free (cContent);
-	if (error != NULL)
-	{
-		cd_warning ("couldn't copy file '%s' (%s)", cFilePath, error->message);
-		g_error_free (error);
+		if (bAlwaysLaunch)
+			pCallback (pUserData);
 		return FALSE;
 	}
+
+	gpointer *pData = g_new (gpointer, 4);
+	pData[0] = GINT_TO_POINTER (bCheckSameProcess);
+	if (bCheckSameProcess)
+		pData[1] = g_strdup_printf ("/proc/%d", iPID);
+	else
+		pData[1] = g_strdup (cProcessName);
+	pData[2] = pCallback;
+	pData[3] = pUserData;
+
+	/* It's not easy to be notified when a non child process is stopped...
+	 * We can't use waitpid (not a child process) or monitor /proc/PID dir (or a
+	 * file into it) with g_file_monitor, poll or inotify => it's not working...
+	 * And for apt-get/dpkg, we can't monitor the lock file with fcntl because
+	 * we need root rights to do that.
+	 * Let's just check every 5 seconds if the PID is still running
+	 */
+	g_timeout_add_seconds (5, (GSourceFunc)_wait_pid, pData);
+
 	return TRUE;
 }
 
@@ -538,8 +627,10 @@ static inline CairoDockDesktopEnv _guess_environment (void)
 	if (cEnv != NULL && *cEnv != '\0')
 		return CAIRO_DOCK_KDE;
 	
+	#ifdef HAVE_X11
 	if (cairo_dock_property_is_present_on_root ("_DT_SAVE_MODE"))
 		return CAIRO_DOCK_XFCE;
+	#endif
 	
 	gchar *cKWin = cairo_dock_launch_command_sync ("pgrep kwin");
 	if (cKWin != NULL && *cKWin != '\0')
@@ -565,22 +656,20 @@ static void init (void)
 void gldi_register_desktop_environment_manager (void)
 {
 	// Manager
-	memset (&myDesktopEnvMgr, 0, sizeof (CairoDesktopEnvManager));
-	myDesktopEnvMgr.mgr.cModuleName 	= "Desktop Env";
-	myDesktopEnvMgr.mgr.init 			= init;
-	myDesktopEnvMgr.mgr.load 			= NULL;
-	myDesktopEnvMgr.mgr.unload 			= NULL;
-	myDesktopEnvMgr.mgr.reload 			= (GldiManagerReloadFunc)NULL;
-	myDesktopEnvMgr.mgr.get_config 		= (GldiManagerGetConfigFunc)NULL;
-	myDesktopEnvMgr.mgr.reset_config	 = (GldiManagerResetConfigFunc)NULL;
+	memset (&myDesktopEnvMgr, 0, sizeof (GldiManager));
+	gldi_object_init (GLDI_OBJECT(&myDesktopEnvMgr), &myManagerObjectMgr, NULL);
+	myDesktopEnvMgr.cModuleName 	= "Desktop Env";
+	// interface
+	myDesktopEnvMgr.init 			= init;
+	myDesktopEnvMgr.load 			= NULL;
+	myDesktopEnvMgr.unload 			= NULL;
+	myDesktopEnvMgr.reload 			= (GldiManagerReloadFunc)NULL;
+	myDesktopEnvMgr.get_config 		= (GldiManagerGetConfigFunc)NULL;
+	myDesktopEnvMgr.reset_config	 = (GldiManagerResetConfigFunc)NULL;
 	// Config
-	myDesktopEnvMgr.mgr.pConfig = (GldiManagerConfigPtr)NULL;
-	myDesktopEnvMgr.mgr.iSizeOfConfig = 0;
+	myDesktopEnvMgr.pConfig = (GldiManagerConfigPtr)NULL;
+	myDesktopEnvMgr.iSizeOfConfig = 0;
 	// data
-	myDesktopEnvMgr.mgr.pData = (GldiManagerDataPtr)NULL;
-	myDesktopEnvMgr.mgr.iSizeOfData = 0;
-	// signals
-	cairo_dock_install_notifications_on_object (&myDesktopEnvMgr, NB_NOTIFICATIONS_DESKTOP_ENV);
-	// register
-	gldi_register_manager (GLDI_MANAGER(&myDesktopEnvMgr));
+	myDesktopEnvMgr.pData = (GldiManagerDataPtr)NULL;
+	myDesktopEnvMgr.iSizeOfData = 0;
 }
