@@ -28,21 +28,26 @@
 #include "cairo-dock-surface-factory.h"
 #include "cairo-dock-config.h"
 #include "cairo-dock-log.h"
-#include "cairo-dock-dock-manager.h"  // cairo_dock_redraw_root_docks
+#include "cairo-dock-dock-manager.h"  // gldi_docks_redraw_all_root
 #include "cairo-dock-draw-opengl.h"
 #include "cairo-dock-container.h"
-#include "cairo-dock-applications-manager.h"  // cairo_dock_foreach_applis
+#include "cairo-dock-applications-manager.h"  // cairo_dock_foreach_appli_icon
 #include "cairo-dock-image-buffer.h"
 #include "cairo-dock-icon-manager.h"
-#include "cairo-dock-notifications.h"
+#include "cairo-dock-icon-facility.h"  // cairo_dock_get_icon_container
+#include "cairo-dock-launcher-manager.h"
+#include "cairo-dock-applet-manager.h"
+#include "cairo-dock-class-icon-manager.h"
 #include "cairo-dock-data-renderer.h"
+#include "cairo-dock-style-manager.h"
 #include "cairo-dock-applications-manager.h"  // myTaskbarParam.bShowAppli
+#include "cairo-dock-windows-manager.h"
 #define _MANAGER_DEF_
 #include "cairo-dock-indicator-manager.h"
 
 // public (manager, config, data)
 CairoIndicatorsParam myIndicatorsParam;
-CairoIndicatorsManager myIndicatorsMgr;
+GldiManager myIndicatorsMgr;
 
 // dependancies
 extern CairoDock *g_pMainDock;
@@ -237,12 +242,12 @@ static void _cairo_dock_draw_class_indicator (cairo_t *pCairoContext, Icon *icon
 static inline gboolean _active_indicator_is_visible (Icon *icon)
 {
 	gboolean bIsActive = FALSE;
-	if (icon->Xid)
+	if (icon->pAppli)
 	{
-		Window xActiveId = cairo_dock_get_current_active_window ();
-		if (xActiveId != 0)
+		GldiWindowActor *pAppli = gldi_windows_get_active ();
+		if (pAppli != NULL)
 		{
-			bIsActive = (icon->Xid == xActiveId);
+			bIsActive = (icon->pAppli == pAppli);
 			if (!bIsActive && icon->pSubDock != NULL)
 			{
 				Icon *subicon;
@@ -250,7 +255,7 @@ static inline gboolean _active_indicator_is_visible (Icon *icon)
 				for (ic = icon->pSubDock->icons; ic != NULL; ic = ic->next)
 				{
 					subicon = ic->data;
-					if (subicon->Xid == xActiveId)
+					if (subicon->pAppli == pAppli)
 					{
 						bIsActive = TRUE;
 						break;
@@ -290,7 +295,7 @@ static gboolean cairo_dock_pre_render_indicator_notification (G_GNUC_UNUSED gpoi
 			_cairo_dock_draw_active_window_indicator_opengl (icon, pDock, pDock->container.fRatio);
 		}
 	}
-	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+	return GLDI_NOTIFICATION_LET_PASS;
 }
 
 static gboolean cairo_dock_render_indicator_notification (G_GNUC_UNUSED gpointer pUserData, Icon *icon, CairoDock *pDock, G_GNUC_UNUSED gboolean *bHasBeenRendered, cairo_t *pCairoContext)
@@ -307,7 +312,7 @@ static gboolean cairo_dock_render_indicator_notification (G_GNUC_UNUSED gpointer
 		{
 			_cairo_dock_draw_appli_indicator (icon, pDock, pCairoContext);
 		}
-		if (icon->pSubDock != NULL && icon->cClass != NULL && s_classIndicatorBuffer.pSurface != NULL && icon->Xid == 0)  // le dernier test est de la paranoia.
+		if (icon->pSubDock != NULL && icon->cClass != NULL && s_classIndicatorBuffer.pSurface != NULL && icon->pAppli == NULL)  // le dernier test est de la paranoia.
 		{
 			_cairo_dock_draw_class_indicator (pCairoContext, icon, pDock->container.bIsHorizontal, pDock->container.fRatio, pDock->container.bDirectionUp);
 		}
@@ -326,12 +331,12 @@ static gboolean cairo_dock_render_indicator_notification (G_GNUC_UNUSED gpointer
 		{
 			_cairo_dock_draw_active_window_indicator_opengl (icon, pDock, pDock->container.fRatio);
 		}
-		if (icon->pSubDock != NULL && icon->cClass != NULL && s_classIndicatorBuffer.iTexture != 0 && icon->Xid == 0)  // le dernier test est de la paranoia.
+		if (icon->pSubDock != NULL && icon->cClass != NULL && s_classIndicatorBuffer.iTexture != 0 && icon->pAppli == NULL)  // le dernier test est de la paranoia.
 		{
 			_cairo_dock_draw_class_indicator_opengl (icon, pDock->container.bIsHorizontal, pDock->container.fRatio, pDock->container.bDirectionUp);
 		}
 	}
-	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+	return GLDI_NOTIFICATION_LET_PASS;
 }
 
 
@@ -401,6 +406,55 @@ static gboolean get_config (GKeyFile *pKeyFile, CairoIndicatorsParam *pIndicator
 	pIndicators->bDrawIndicatorOnAppli = cairo_dock_get_boolean_key_value (pKeyFile, "Indicators", "indic on appli", &bFlushConfFileNeeded, FALSE, "TaskBar", NULL);
 	
 	//\__________________ On recupere l'indicateur de fenetre active.
+	pIndicators->bActiveFillFrame = (cairo_dock_get_integer_key_value (pKeyFile, "Indicators", "active frame", &bFlushConfFileNeeded, 0, NULL, NULL) == 0);
+	int iIndicType = cairo_dock_get_integer_key_value (pKeyFile, "Indicators", "active style", &bFlushConfFileNeeded, -1, NULL, NULL);  // -1 in case the key doesn't exist yet
+	if (iIndicType == -1)  // old param < 3.4
+	{
+		iIndicType = g_key_file_get_integer (pKeyFile, "Indicators", "active indic type", NULL);
+		
+		if (iIndicType == 0)
+		{
+			gchar *cIndicatorImageName = cairo_dock_get_string_key_value (pKeyFile, "Indicators", "active indicator", &bFlushConfFileNeeded, NULL, NULL, NULL);
+			if (cIndicatorImageName != NULL)  // ensure the image exists
+			{
+				pIndicators->cActiveIndicatorImagePath = cairo_dock_search_image_s_path (cIndicatorImageName);
+				g_free (cIndicatorImageName);
+			}
+		}
+		if (pIndicators->cActiveIndicatorImagePath != NULL)
+			iIndicType = 1;
+		else
+			iIndicType = 2;
+		g_key_file_set_integer (pKeyFile, "Indicators", "active style", iIndicType);
+		
+		int iActiveLineWidth = g_key_file_get_integer (pKeyFile, "Indicators", "active line width", NULL);
+		pIndicators->bActiveFillFrame = (iActiveLineWidth == 0);
+		g_key_file_set_integer (pKeyFile, "Indicators", "active frame", pIndicators->bActiveFillFrame ? 0:1);
+		if (iActiveLineWidth == 0)
+			g_key_file_set_integer (pKeyFile, "Indicators", "active line width", 2);
+	}
+	if (iIndicType == 1)
+	{
+		gchar *cIndicatorImageName = cairo_dock_get_string_key_value (pKeyFile, "Indicators", "active indicator", &bFlushConfFileNeeded, NULL, NULL, NULL);
+		if (cIndicatorImageName != NULL && pIndicators->cActiveIndicatorImagePath == NULL)  // ensure the image exists
+			pIndicators->cActiveIndicatorImagePath = cairo_dock_search_image_s_path (cIndicatorImageName);
+		g_free (cIndicatorImageName);
+		if (pIndicators->cActiveIndicatorImagePath == NULL)
+			iIndicType = 0;
+	}
+	if (iIndicType == 0)
+	{
+		pIndicators->bActiveUseDefaultColors = TRUE;
+	}
+	else if (iIndicType == 2)
+	{
+		GldiColor couleur_active = {{0., 0.4, 0.8, 0.5}};
+		cairo_dock_get_color_key_value (pKeyFile, "Indicators", "active color", &bFlushConfFileNeeded, &pIndicators->fActiveColor, &couleur_active, "Icons", NULL);
+		pIndicators->iActiveLineWidth = cairo_dock_get_integer_key_value (pKeyFile, "Indicators", "active line width", &bFlushConfFileNeeded, 3, "Icons", NULL);
+		pIndicators->iActiveCornerRadius = cairo_dock_get_integer_key_value (pKeyFile, "Indicators", "active corner radius", &bFlushConfFileNeeded, 6, "Icons", NULL);
+	}
+	
+	/**
 	int iIndicType = cairo_dock_get_integer_key_value (pKeyFile, "Indicators", "active indic type", &bFlushConfFileNeeded, -1, NULL, NULL);  // -1 pour pouvoir intercepter le cas ou la cle n'existe pas.
 	
 	if (iIndicType == 0 || iIndicType == -1)  // image or new key => get the image
@@ -419,13 +473,13 @@ static gboolean get_config (GKeyFile *pKeyFile, CairoIndicatorsParam *pIndicator
 	
 	if (pIndicators->cActiveIndicatorImagePath == NULL)  // 'frame' option, or no image defined, or nonexistent image => load the frame
 	{
-		double couleur_active[4] = {0., 0.4, 0.8, 0.5};
-		cairo_dock_get_double_list_key_value (pKeyFile, "Indicators", "active color", &bFlushConfFileNeeded, pIndicators->fActiveColor, 4, couleur_active, "Icons", NULL);
+		GldiColor couleur_active = {{0., 0.4, 0.8, 0.5}};
+		cairo_dock_get_color_key_value (pKeyFile, "Indicators", "active color", &bFlushConfFileNeeded, &pIndicators->fActiveColor, &couleur_active, "Icons", NULL);
 		pIndicators->iActiveLineWidth = cairo_dock_get_integer_key_value (pKeyFile, "Indicators", "active line width", &bFlushConfFileNeeded, 3, "Icons", NULL);
 		pIndicators->iActiveCornerRadius = cairo_dock_get_integer_key_value (pKeyFile, "Indicators", "active corner radius", &bFlushConfFileNeeded, 6, "Icons", NULL);
 	}  // donc ici si on choisit le mode "image" sans en definir une, le alpha de la couleur reste a 0 => aucun indicateur
-	
-	pIndicators->bActiveIndicatorAbove = cairo_dock_get_boolean_key_value (pKeyFile, "Indicators", "active frame position", &bFlushConfFileNeeded, TRUE, "Icons", NULL);
+	*/
+	pIndicators->bActiveIndicatorAbove = cairo_dock_get_boolean_key_value (pKeyFile, "Indicators", "active frame position", &bFlushConfFileNeeded, FALSE, "Icons", NULL);
 	
 	//\__________________ On recupere l'indicateur de classe groupee.
 	pIndicators->bUseClassIndic = (cairo_dock_get_integer_key_value (pKeyFile, "Indicators", "use class indic", &bFlushConfFileNeeded, 0, NULL, NULL) == 0);
@@ -446,13 +500,18 @@ static gboolean get_config (GKeyFile *pKeyFile, CairoIndicatorsParam *pIndicator
 	}
 	
 	//\__________________ Progress bar.
-	double start_color[4] = {.53, .53, .53, .85};  // grey
-	cairo_dock_get_double_list_key_value (pKeyFile, "Indicators", "bar_color_start", &bFlushConfFileNeeded, pIndicators->fBarColorStart, 4, start_color, NULL, NULL);
-	double stop_color[4] = {.87, .87, .87, .85};  // grey (lighter)
-	cairo_dock_get_double_list_key_value (pKeyFile, "Indicators", "bar_color_stop", &bFlushConfFileNeeded, pIndicators->fBarColorStop, 4, stop_color, NULL, NULL);
-	pIndicators->bBarHasOutline = cairo_dock_get_boolean_key_value (pKeyFile, "Indicators", "bar_outline", &bFlushConfFileNeeded, TRUE, NULL, NULL);
-	double outline_color[4] = {1, 1, 1, .85};  // white
-	cairo_dock_get_double_list_key_value (pKeyFile, "Indicators", "bar_color_outline", &bFlushConfFileNeeded, pIndicators->fBarColorOutline, 4, outline_color, NULL, NULL);
+	pIndicators->bBarUseDefaultColors = (cairo_dock_get_integer_key_value (pKeyFile, "Indicators", "bar_colors", &bFlushConfFileNeeded, 1, NULL, NULL) == 0);
+	GldiColor start_color = {{.53, .53, .53, .85}};  // grey
+	cairo_dock_get_color_key_value (pKeyFile, "Indicators", "bar_color_start", &bFlushConfFileNeeded, &pIndicators->fBarColorStart, &start_color, NULL, NULL);
+	GldiColor stop_color= {{.87, .87, .87, .85}};  // grey (lighter)
+	cairo_dock_get_color_key_value (pKeyFile, "Indicators", "bar_color_stop", &bFlushConfFileNeeded, &pIndicators->fBarColorStop, &stop_color, NULL, NULL);
+	GldiColor outline_color = {{1, 1, 1, .85}};  // white
+	cairo_dock_get_color_key_value (pKeyFile, "Indicators", "bar_color_outline", &bFlushConfFileNeeded, &pIndicators->fBarColorOutline, &outline_color, NULL, NULL);
+	if (g_key_file_has_key (pKeyFile, "Indicators", "bar_outline", NULL))  // old param < 3.4
+	{
+		if (! g_key_file_get_boolean (pKeyFile, "Indicators", "bar_outline", NULL))
+			pIndicators->fBarColorOutline.rgba.alpha = 0.;
+	}
 	pIndicators->iBarThickness = cairo_dock_get_integer_key_value (pKeyFile, "Indicators", "bar_thickness", &bFlushConfFileNeeded, 4, NULL, NULL);
 	
 	return bFlushConfFileNeeded;
@@ -489,7 +548,7 @@ static inline void _load_task_indicator (const gchar *cIndicatorImagePath, doubl
 		fLauncherHeight * fScale,
 		CAIRO_DOCK_KEEP_RATIO);
 }
-static inline void _load_active_window_indicator (const gchar *cImagePath, double fMaxScale, double fCornerRadius, double fLineWidth, double *fActiveColor)
+static inline void _load_active_window_indicator (const gchar *cImagePath, double fMaxScale, double fCornerRadius, double fLineWidth, GldiColor *fActiveColor, gboolean bDefaultValues, gboolean bFillFrame)
 {
 	cairo_dock_unload_image_buffer (&s_activeIndicatorBuffer);
 	
@@ -506,11 +565,18 @@ static inline void _load_active_window_indicator (const gchar *cImagePath, doubl
 			iHeight,
 			CAIRO_DOCK_FILL_SPACE);
 	}
-	else if (fActiveColor[3] > 0)
+	else
 	{
 		cairo_surface_t *pSurface = cairo_dock_create_blank_surface (iWidth, iHeight);
 		cairo_t *pCairoContext = cairo_create (pSurface);
 		
+		if (bDefaultValues)
+		{
+			fCornerRadius = myStyleParam.iCornerRadius;
+			fLineWidth = 2*myStyleParam.iLineWidth;  // *2 or it will be too light
+		}
+		if (bFillFrame)
+			fLineWidth = 0;
 		fCornerRadius = MIN (fCornerRadius, (iWidth - fLineWidth) / 2);
 		double fFrameWidth = iWidth - (2 * fCornerRadius + fLineWidth);
 		double fFrameHeight = iHeight - 2 * fLineWidth;
@@ -518,16 +584,30 @@ static inline void _load_active_window_indicator (const gchar *cImagePath, doubl
 		double fDockOffsetY = fLineWidth/2;
 		cairo_dock_draw_frame (pCairoContext, fCornerRadius, fLineWidth, fFrameWidth, fFrameHeight, fDockOffsetX, fDockOffsetY, 1, 0., CAIRO_DOCK_HORIZONTAL, TRUE);
 		
-		cairo_set_source_rgba (pCairoContext, fActiveColor[0], fActiveColor[1], fActiveColor[2], fActiveColor[3]);
-		if (fLineWidth > 0)
+		if (bDefaultValues)
 		{
-			cairo_set_line_width (pCairoContext, fLineWidth);
-			cairo_stroke (pCairoContext);
+			if (bFillFrame)
+				gldi_style_colors_set_selected_bg_color (pCairoContext);
+			else
+			{
+				gldi_style_colors_set_child_color (pCairoContext);  // for a line, the selected color is often too close to the bg color
+				cairo_set_line_width (pCairoContext, fLineWidth);
+			}
 		}
 		else
+		{
+			gldi_color_set_cairo (pCairoContext, fActiveColor);
+			if (! bFillFrame)
+				cairo_set_line_width (pCairoContext, fLineWidth);
+		}
+		if (bFillFrame)
 		{
 			cairo_fill (pCairoContext);
 		}
+		else
+		{
+			cairo_stroke (pCairoContext);
+		}
 		cairo_destroy (pCairoContext);
 		
 		cairo_dock_load_image_buffer_from_surface (&s_activeIndicatorBuffer,
@@ -555,7 +635,7 @@ static void load (void)
 	
 	_load_task_indicator (myTaskbarParam.bShowAppli && (myTaskbarParam.bMixLauncherAppli || myIndicatorsParam.bDrawIndicatorOnAppli) ? myIndicatorsParam.cIndicatorImagePath : NULL, fMaxScale, myIndicatorsParam.fIndicatorRatio);
 	
-	_load_active_window_indicator (myIndicatorsParam.cActiveIndicatorImagePath, fMaxScale, myIndicatorsParam.iActiveCornerRadius, myIndicatorsParam.iActiveLineWidth, myIndicatorsParam.fActiveColor);
+	_load_active_window_indicator (myIndicatorsParam.cActiveIndicatorImagePath, fMaxScale, myIndicatorsParam.iActiveCornerRadius, myIndicatorsParam.iActiveLineWidth, &myIndicatorsParam.fActiveColor, myIndicatorsParam.bActiveUseDefaultColors, myIndicatorsParam.bActiveFillFrame);
 	
 	_load_class_indicator (myTaskbarParam.bShowAppli && myTaskbarParam.bGroupAppliByClass ? myIndicatorsParam.cClassIndicatorImagePath : NULL);
 }
@@ -565,21 +645,23 @@ static void load (void)
  /// RELOAD ///
 //////////////
 
-static void _set_indicator (Icon *pIcon, G_GNUC_UNUSED CairoContainer *pContainer, gpointer data)
+static void _set_indicator (Icon *pIcon, gpointer data)
 {
 	pIcon->bHasIndicator = GPOINTER_TO_INT (data);
 }
-static void _reload_progress_bar (Icon *pIcon, CairoContainer *pContainer, G_GNUC_UNUSED gpointer data)
+static void _reload_progress_bar (Icon *pIcon, G_GNUC_UNUSED gpointer data)
 {
 	if (cairo_dock_get_icon_data_renderer (pIcon) != NULL)
 	{
+		GldiContainer *pContainer = cairo_dock_get_icon_container (pIcon);
 		cairo_dock_reload_data_renderer_on_icon (pIcon, pContainer);
 	}
 }
-static void _reload_multi_appli (Icon *icon, CairoContainer *pContainer, G_GNUC_UNUSED gpointer data)
+static void _reload_multi_appli (Icon *icon, G_GNUC_UNUSED gpointer data)
 {
 	if (CAIRO_DOCK_IS_MULTI_APPLI (icon))
 	{
+		GldiContainer *pContainer = cairo_dock_get_icon_container (icon);
 		cairo_dock_load_icon_image (icon, pContainer);
 		if (!myIndicatorsParam.bUseClassIndic)
 			cairo_dock_draw_subdock_content_on_icon (icon, CAIRO_DOCK (pContainer));
@@ -589,60 +671,55 @@ static void reload (CairoIndicatorsParam *pPrevIndicators, CairoIndicatorsParam
 {
 	double fMaxScale = 1 + myIconsParam.fAmplitude;
 	
-	if (cairo_dock_strings_differ (pPrevIndicators->cIndicatorImagePath, pIndicators->cIndicatorImagePath) ||
-		pPrevIndicators->bIndicatorOnIcon != pIndicators->bIndicatorOnIcon ||
-		pPrevIndicators->fIndicatorRatio != pIndicators->fIndicatorRatio)
+	if (g_strcmp0 (pPrevIndicators->cIndicatorImagePath, pIndicators->cIndicatorImagePath) != 0
+	|| pPrevIndicators->bIndicatorOnIcon != pIndicators->bIndicatorOnIcon
+	|| pPrevIndicators->fIndicatorRatio != pIndicators->fIndicatorRatio)
 	{
 		_load_task_indicator (myTaskbarParam.bShowAppli && (myTaskbarParam.bMixLauncherAppli || myIndicatorsParam.bDrawIndicatorOnAppli) ? pIndicators->cIndicatorImagePath : NULL, fMaxScale, pIndicators->fIndicatorRatio);
 	}
 	
-	if (cairo_dock_strings_differ (pPrevIndicators->cActiveIndicatorImagePath, pIndicators->cActiveIndicatorImagePath) ||
-		pPrevIndicators->iActiveCornerRadius != pIndicators->iActiveCornerRadius ||
-		pPrevIndicators->iActiveLineWidth != pIndicators->iActiveLineWidth ||
-		cairo_dock_colors_differ (pPrevIndicators->fActiveColor, pIndicators->fActiveColor))
+	if (g_strcmp0 (pPrevIndicators->cActiveIndicatorImagePath, pIndicators->cActiveIndicatorImagePath) != 0
+	|| pPrevIndicators->iActiveCornerRadius != pIndicators->iActiveCornerRadius
+	|| pPrevIndicators->iActiveLineWidth != pIndicators->iActiveLineWidth
+	|| gldi_color_compare (&pPrevIndicators->fActiveColor, &pIndicators->fActiveColor)
+	|| pPrevIndicators->bActiveUseDefaultColors != pIndicators->bActiveUseDefaultColors
+	|| pPrevIndicators->bActiveFillFrame != pIndicators->bActiveFillFrame)
 	{
 		_load_active_window_indicator (pIndicators->cActiveIndicatorImagePath,
 			fMaxScale,
 			pIndicators->iActiveCornerRadius,
 			pIndicators->iActiveLineWidth,
-			pIndicators->fActiveColor);
+			&pIndicators->fActiveColor,
+			pIndicators->bActiveUseDefaultColors,
+			pIndicators->bActiveFillFrame);
 	}
 	
-	if (cairo_dock_strings_differ (pPrevIndicators->cClassIndicatorImagePath, pIndicators->cClassIndicatorImagePath) ||
-		pPrevIndicators->bUseClassIndic != pIndicators->bUseClassIndic)
+	if (g_strcmp0 (pPrevIndicators->cClassIndicatorImagePath, pIndicators->cClassIndicatorImagePath) != 0
+	|| pPrevIndicators->bUseClassIndic != pIndicators->bUseClassIndic)
 	{
 		_load_class_indicator (myTaskbarParam.bShowAppli && myTaskbarParam.bGroupAppliByClass ? pIndicators->cClassIndicatorImagePath : NULL);
 		
 		if (pPrevIndicators->bUseClassIndic != pIndicators->bUseClassIndic)  // on recharge les icones pointant sur une classe (qui sont dans le main dock).
 		{
-			cairo_dock_foreach_icons_in_docks ((CairoDockForeachIconFunc)_reload_multi_appli, NULL);
+			gldi_icons_foreach_in_docks ((GldiIconFunc)_reload_multi_appli, NULL);
 		}
 	}
 	
 	if (pPrevIndicators->bDrawIndicatorOnAppli != pIndicators->bDrawIndicatorOnAppli)
 	{
-		cairo_dock_foreach_applis ((CairoDockForeachIconFunc) _set_indicator, FALSE, GINT_TO_POINTER (pIndicators->bDrawIndicatorOnAppli));
+		cairo_dock_foreach_appli_icon ((GldiIconFunc) _set_indicator, GINT_TO_POINTER (pIndicators->bDrawIndicatorOnAppli));
 	}
 	
-	if (pPrevIndicators->fBarColorStart[0] != pIndicators->fBarColorStart[0]
-	|| pPrevIndicators->fBarColorStart[1] != pIndicators->fBarColorStart[1]
-	|| pPrevIndicators->fBarColorStart[2] != pIndicators->fBarColorStart[2]
-	|| pPrevIndicators->fBarColorStart[3] != pIndicators->fBarColorStart[3]
-	|| pPrevIndicators->fBarColorStop[0] != pIndicators->fBarColorStop[0]
-	|| pPrevIndicators->fBarColorStop[1] != pIndicators->fBarColorStop[1]
-	|| pPrevIndicators->fBarColorStop[2] != pIndicators->fBarColorStop[2]
-	|| pPrevIndicators->fBarColorStop[3] != pIndicators->fBarColorStop[3]
-	|| pPrevIndicators->iBarThickness != pIndicators->iBarThickness
-	|| pPrevIndicators->bBarHasOutline != pIndicators->bBarHasOutline
-	|| pPrevIndicators->fBarColorOutline[0] != pIndicators->fBarColorOutline[0]
-	|| pPrevIndicators->fBarColorOutline[1] != pIndicators->fBarColorOutline[1]
-	|| pPrevIndicators->fBarColorOutline[2] != pIndicators->fBarColorOutline[2]
-	|| pPrevIndicators->fBarColorOutline[3] != pIndicators->fBarColorOutline[3])
+	if (pPrevIndicators->bBarUseDefaultColors != pIndicators->bBarUseDefaultColors
+	|| gldi_color_compare (&pPrevIndicators->fBarColorStart, &pIndicators->fBarColorStart)
+	|| gldi_color_compare (&pPrevIndicators->fBarColorStop, &pIndicators->fBarColorStop)
+	|| gldi_color_compare (&pPrevIndicators->fBarColorOutline, &pIndicators->fBarColorOutline)
+	|| pPrevIndicators->iBarThickness != pIndicators->iBarThickness)
 	{
-		cairo_dock_foreach_icons ((CairoDockForeachIconFunc) _reload_progress_bar, NULL);
+		gldi_icons_foreach ((GldiIconFunc) _reload_progress_bar, NULL);
 	}
 	
-	cairo_dock_redraw_root_docks (FALSE);  // tous les docks (main dock et les autres qui peuvent contenir des applets avec un indicateur).
+	gldi_docks_redraw_all_root ();
 }
 
 
@@ -662,16 +739,37 @@ static void unload (void)
  /// INIT ///
 ////////////
 
+static gboolean on_style_changed (G_GNUC_UNUSED gpointer data)
+{
+	cd_debug ("Indic: style changed to %d", myIndicatorsParam.bBarUseDefaultColors);
+	if (myIndicatorsParam.bBarUseDefaultColors)  // reload progress bars
+	{
+		cd_debug ("reload indicators...");
+		gldi_icons_foreach ((GldiIconFunc) _reload_progress_bar, NULL);
+	}
+	if (myIndicatorsParam.bActiveUseDefaultColors)  // reload active indicator
+	{
+		cd_debug ("reload active indicator...");
+		double fMaxScale = 1 + myIconsParam.fAmplitude;
+		_load_active_window_indicator (myIndicatorsParam.cActiveIndicatorImagePath, fMaxScale, myIndicatorsParam.iActiveCornerRadius, myIndicatorsParam.iActiveLineWidth, &myIndicatorsParam.fActiveColor, myIndicatorsParam.bActiveUseDefaultColors, myIndicatorsParam.bActiveFillFrame);
+	}
+	return GLDI_NOTIFICATION_LET_PASS;
+}
+
 static void init (void)
 {
-	cairo_dock_register_notification_on_object (&myIconsMgr,
+	gldi_object_register_notification (&myIconObjectMgr,
 		NOTIFICATION_PRE_RENDER_ICON,
-		(CairoDockNotificationFunc) cairo_dock_pre_render_indicator_notification,
-		CAIRO_DOCK_RUN_FIRST, NULL);
-	cairo_dock_register_notification_on_object (&myIconsMgr,
+		(GldiNotificationFunc) cairo_dock_pre_render_indicator_notification,
+		GLDI_RUN_FIRST, NULL);
+	gldi_object_register_notification (&myIconObjectMgr,
 		NOTIFICATION_RENDER_ICON,
-		(CairoDockNotificationFunc) cairo_dock_render_indicator_notification,
-		CAIRO_DOCK_RUN_AFTER, NULL);
+		(GldiNotificationFunc) cairo_dock_render_indicator_notification,
+		GLDI_RUN_AFTER, NULL);
+	gldi_object_register_notification (&myStyleMgr,
+		NOTIFICATION_STYLE_CHANGED,
+		(GldiNotificationFunc) on_style_changed,
+		GLDI_RUN_AFTER, NULL);
 }
 
 
@@ -682,26 +780,26 @@ static void init (void)
 void gldi_register_indicators_manager (void)
 {
 	// Manager
-	memset (&myIndicatorsMgr, 0, sizeof (CairoIndicatorsManager));
-	myIndicatorsMgr.mgr.cModuleName 	= "Indicators";
-	myIndicatorsMgr.mgr.init 			= init;
-	myIndicatorsMgr.mgr.load 			= load;
-	myIndicatorsMgr.mgr.unload 			= unload;
-	myIndicatorsMgr.mgr.reload 			= (GldiManagerReloadFunc)reload;
-	myIndicatorsMgr.mgr.get_config 		= (GldiManagerGetConfigFunc)get_config;
-	myIndicatorsMgr.mgr.reset_config 	= (GldiManagerResetConfigFunc)reset_config;
+	memset (&myIndicatorsMgr, 0, sizeof (GldiManager));
+	gldi_object_init (GLDI_OBJECT(&myIndicatorsMgr), &myManagerObjectMgr, NULL);
+	myIndicatorsMgr.cModuleName  = "Indicators";
+	// interface
+	myIndicatorsMgr.init         = init;
+	myIndicatorsMgr.load         = load;
+	myIndicatorsMgr.unload       = unload;
+	myIndicatorsMgr.reload       = (GldiManagerReloadFunc)reload;
+	myIndicatorsMgr.get_config   = (GldiManagerGetConfigFunc)get_config;
+	myIndicatorsMgr.reset_config = (GldiManagerResetConfigFunc)reset_config;
 	// Config
 	memset (&myIndicatorsParam, 0, sizeof (CairoIndicatorsParam));
-	myIndicatorsMgr.mgr.pConfig = (GldiManagerConfigPtr)&myIndicatorsParam;
-	myIndicatorsMgr.mgr.iSizeOfConfig = sizeof (CairoIndicatorsParam);
+	myIndicatorsMgr.pConfig = (GldiManagerConfigPtr)&myIndicatorsParam;
+	myIndicatorsMgr.iSizeOfConfig = sizeof (CairoIndicatorsParam);
 	// data
 	memset (&s_indicatorBuffer, 0, sizeof (CairoDockImageBuffer));
 	memset (&s_activeIndicatorBuffer, 0, sizeof (CairoDockImageBuffer));
 	memset (&s_classIndicatorBuffer, 0, sizeof (CairoDockImageBuffer));
-	myIndicatorsMgr.mgr.pData = (GldiManagerDataPtr)NULL;
-	myIndicatorsMgr.mgr.iSizeOfData = 0;
+	myIndicatorsMgr.pData = (GldiManagerDataPtr)NULL;
+	myIndicatorsMgr.iSizeOfData = 0;
 	// signals
-	cairo_dock_install_notifications_on_object (&myIndicatorsMgr, NB_NOTIFICATIONS_INDICATORS);
-	// register
-	gldi_register_manager (GLDI_MANAGER(&myIndicatorsMgr));
+	gldi_object_install_notifications (&myIndicatorsMgr, NB_NOTIFICATIONS_INDICATORS);
 }
