@@ -28,22 +28,21 @@
 #include <glib/gi18n.h>
 
 #include "gldi-config.h"
-#include "cairo-dock-config.h"
 #include "cairo-dock-keyfile-utilities.h"
 #include "cairo-dock-file-manager.h"  // cairo_dock_copy_file
 #include "cairo-dock-launcher-manager.h" // cairo_dock_get_command_with_right_terminal
 #include "cairo-dock-dock-manager.h"
-#include "cairo-dock-module-factory.h"
+#include "cairo-dock-module-manager.h"  // gldi_module_foreach
 #include "cairo-dock-backends-manager.h"
 #include "cairo-dock-dialog-manager.h"
-//#include "cairo-dock-gui-manager.h"
+#include "cairo-dock-icon-facility.h"  // gldi_icons_get_any_without_dialog
 #include "cairo-dock-task.h"
 #include "cairo-dock-log.h"
+#include "cairo-dock-utils.h"  // cairo_dock_get_command_with_right_terminal
 #include "cairo-dock-packages.h"
 #include "cairo-dock-core.h"
+#include "cairo-dock-applications-manager.h"  // cairo_dock_get_current_active_icon
 #include "cairo-dock-dock-facility.h"
-//#include "cairo-dock-opengl.h"
-#include "cairo-dock-global-variables.h"
 #include "cairo-dock-themes-manager.h"
 
 // public data
@@ -62,6 +61,7 @@ static gchar *s_cLocalThemeDirPath = NULL;
 static gchar *s_cDistantThemeDirName = NULL;
 
 #define CAIRO_DOCK_MODIFIED_THEME_FILE ".cairo-dock-need-save"
+// the structure of a theme (including the current theme, except that it doesn't have an extras folders)
 #define CAIRO_DOCK_LOCAL_EXTRAS_DIR "extras"
 #define CAIRO_DOCK_LAUNCHERS_DIR "launchers"
 #define CAIRO_DOCK_PLUG_INS_DIR "plug-ins"
@@ -69,7 +69,6 @@ static gchar *s_cDistantThemeDirName = NULL;
 #define CAIRO_DOCK_LOCAL_IMAGES_DIR "images"
 
 // dependancies
-//extern gboolean g_bUseOpenGL;
 extern CairoDock *g_pMainDock;
 
 
@@ -187,8 +186,11 @@ gboolean cairo_dock_export_current_theme (const gchar *cNewThemeName, gboolean b
 	{
 		cd_debug ("  This theme will be updated");
 		gchar *cQuestion = g_strdup_printf (_("Are you sure you want to overwrite theme %s?"), cNewThemeName);
-		Icon *pIcon = cairo_dock_get_dialogless_icon ();
-		int iClickedButton = cairo_dock_show_dialog_and_wait (cQuestion,
+		Icon *pIcon = cairo_dock_get_current_active_icon ();  // it's most probably the icon corresponding to the configuration window
+		if (pIcon == NULL || cairo_dock_get_icon_container (pIcon) == NULL)  // if not available, get any icon
+			pIcon = gldi_icons_get_any_without_dialog ();
+		cd_debug ("%s", pIcon->cName);
+		int iClickedButton = gldi_dialog_show_and_wait (cQuestion,
 			pIcon, CAIRO_CONTAINER (g_pMainDock),
 			GLDI_SHARE_DATA_DIR"/"CAIRO_DOCK_ICON, NULL);
 		g_free (cQuestion);
@@ -259,7 +261,7 @@ gboolean cairo_dock_export_current_theme (const gchar *cNewThemeName, gboolean b
 	struct tm currentTime;
 	localtime_r (&epoch, &currentTime);
 	char cDateBuffer[50+1];
-	strftime (cDateBuffer, 50, "%a %d %b, %R", &currentTime);
+	strftime (cDateBuffer, 50, "%a %d %b %Y, %R", &currentTime);
 	gchar *cMessage = g_strdup_printf ("%s\n %s", _("Last modification on:"), cDateBuffer);
 	gchar *cReadmeFile = g_strdup_printf ("%s/%s", cNewThemePath, "readme");
 	g_file_set_contents (cReadmeFile,
@@ -290,11 +292,15 @@ gboolean cairo_dock_export_current_theme (const gchar *cNewThemeName, gboolean b
 	return bThemeSaved;
 }
 
-gboolean cairo_dock_package_current_theme (const gchar *cThemeName)
+gboolean cairo_dock_package_current_theme (const gchar *cThemeName, const gchar *cDirPath)
 {
 	g_return_val_if_fail (cThemeName != NULL, FALSE);
+	gboolean bSuccess = FALSE;
 
 	gchar *cNewThemeName = _escape_string_for_filename (cThemeName);
+	if (cDirPath == NULL || *cDirPath == '\0'
+		|| (g_file_test (cDirPath, G_FILE_TEST_EXISTS) && g_file_test (cDirPath, G_FILE_TEST_IS_REGULAR))) // exist but not a directory
+		cDirPath = g_getenv ("HOME");
 	
 	cairo_dock_extract_package_type_from_name (cNewThemeName);
 	
@@ -304,8 +310,8 @@ gboolean cairo_dock_package_current_theme (const gchar *cThemeName)
 	if (bScriptFound)
 	{
 		int r;
-		gchar *cCommand = g_strdup_printf ("%s '%s'",
-			cPackageBuilderPath, cNewThemeName);
+		gchar *cCommand = g_strdup_printf ("%s '%s' '%s'",
+			cPackageBuilderPath, cNewThemeName, cDirPath);
 		gchar *cFullCommand = cairo_dock_get_command_with_right_terminal (cCommand);
 		r = system (cFullCommand); // we need to wait...
 		if (r != 0)
@@ -314,18 +320,28 @@ gboolean cairo_dock_package_current_theme (const gchar *cThemeName)
 			r = system (cCommand); // relaunch it without the terminal and wait
 			if (r != 0)
 				cd_warning ("Not able to launch this command: %s", cCommand);
+			else
+				bSuccess = TRUE;
 		}
+		else
+			bSuccess = TRUE;
 		g_free (cCommand);
 		g_free (cFullCommand);
-		cairo_dock_show_general_message (
-			_("Your theme should now be available in your 'Home' directory."),
-			8000);
 	}
 	else
 		cd_warning ("the package builder script was not found !");
 
+	if (bSuccess)
+	{
+		gchar *cGeneralMessage = g_strdup_printf ("%s %s", _("Your theme should now be available in this directory:"), cDirPath);
+		gldi_dialog_show_general_message (cGeneralMessage, 8000);
+		g_free (cGeneralMessage);
+	}
+	else
+		gldi_dialog_show_general_message (_("Error when launching 'cairo-dock-package-theme' script"), 8000);
+
 	g_free (cNewThemeName);
-	return bScriptFound;
+	return bSuccess;
 }
 gchar *cairo_dock_depackage_theme (const gchar *cPackagePath)
 {
@@ -343,7 +359,7 @@ gchar *cairo_dock_depackage_theme (const gchar *cPackagePath)
 		cNewThemePath = cairo_dock_download_archive (cPackagePath, g_cThemesDirPath);
 		if (cNewThemePath == NULL)
 		{
-			cairo_dock_show_temporary_dialog_with_icon_printf (_("Could not access remote file %s. Maybe the server is down.\nPlease retry later or contact us at glx-dock.org."), NULL, NULL, 0, NULL, cPackagePath);
+			gldi_dialog_show_temporary_with_icon_printf (_("Could not access remote file %s. Maybe the server is down.\nPlease retry later or contact us at glx-dock.org."), NULL, NULL, 0, NULL, cPackagePath);
 		}
 	}
 	return cNewThemePath;
@@ -360,9 +376,11 @@ gboolean cairo_dock_delete_themes (gchar **cThemesList)
 		g_string_printf (sCommand, _("Are you sure you want to delete theme %s?"), cThemesList[0]);
 	else
 		g_string_printf (sCommand, _("Are you sure you want to delete these themes?"));
-	Icon *pIcon = cairo_dock_get_dialogless_icon ();
-	int iClickedButton = cairo_dock_show_dialog_and_wait (sCommand->str,
-		pIcon, CAIRO_CONTAINER (g_pMainDock),
+	Icon *pIcon = cairo_dock_get_current_active_icon ();  // it's most probably the icon corresponding to the configuration window
+	if (pIcon == NULL || cairo_dock_get_icon_container (pIcon) == NULL)  // if not available, get any icon
+		pIcon = gldi_icons_get_any_without_dialog ();
+	int iClickedButton = gldi_dialog_show_and_wait (sCommand->str,
+		pIcon, cairo_dock_get_icon_container (pIcon),
 		GLDI_SHARE_DATA_DIR"/"CAIRO_DOCK_ICON, NULL);
 	if (iClickedButton == 0 || iClickedButton == -1)  // ok button or Enter.
 	{
@@ -391,7 +409,7 @@ gboolean cairo_dock_delete_themes (gchar **cThemesList)
 	return bThemeDeleted;
 }
 
-static gboolean _find_module_from_user_data_dir (G_GNUC_UNUSED gchar *cModuleName, CairoDockModule *pModule, const gchar *cUserDataDirName)
+static gboolean _find_module_from_user_data_dir (G_GNUC_UNUSED gchar *cModuleName, GldiModule *pModule, const gchar *cUserDataDirName)
 {
 	if (pModule->pVisitCard->cUserDataDir && strcmp (cUserDataDirName, pModule->pVisitCard->cUserDataDir) == 0)
 		return TRUE;
@@ -424,21 +442,28 @@ static gchar *_cairo_dock_get_theme_path (const gchar *cThemeName)  // a theme n
 	return cNewThemePath;
 }
 
+static void _launch_cmd (const gchar *cCommand)
+{
+	cd_debug ("%s", cCommand);
+	int r = system (cCommand);
+	if (r < 0)
+		cd_warning ("Not able to launch this command: %s", cCommand);
+}
+
 static gboolean _cairo_dock_import_local_theme (const gchar *cNewThemePath, gboolean bLoadBehavior, gboolean bLoadLaunchers)
 {
 	g_return_val_if_fail (cNewThemePath != NULL && g_file_test (cNewThemePath, G_FILE_TEST_EXISTS), FALSE);
 	
-	//\___________________ On charge les parametres de comportement globaux et de chaque dock.
+	//\___________________ We load global behaviour parameters for each dock.
 	GString *sCommand = g_string_new ("");
-	int r;
 	cd_message ("Applying changes ...");
 	if (g_pMainDock == NULL || bLoadBehavior)
 	{
+		g_string_printf (sCommand, "rm -f \"%s\"/*.conf", g_cCurrentThemePath);
+		_launch_cmd (sCommand->str);
+
 		g_string_printf (sCommand, "cp \"%s\"/*.conf \"%s\"", cNewThemePath, g_cCurrentThemePath);
-		cd_debug ("%s", sCommand->str);
-		r = system (sCommand->str);
-		if (r < 0)
-			cd_warning ("Not able to launch this command: %s", sCommand->str);
+		_launch_cmd (sCommand->str);
 	}
 	else
 	{
@@ -466,144 +491,103 @@ static gboolean _cairo_dock_import_local_theme (const gchar *cNewThemePath, gboo
 		g_dir_close (dir);
 	}
 	
-	//\___________________ On charge les icones.
+	//\___________________ We load icons
 	if (bLoadLaunchers)
 	{
 		g_string_printf (sCommand, "rm -f \"%s\"/*", g_cCurrentIconsPath);
-		cd_debug ("%s", sCommand->str);
-		r = system (sCommand->str);
-		if (r < 0)
-			cd_warning ("Not able to launch this command: %s", sCommand->str);
+		_launch_cmd (sCommand->str);
 		g_string_printf (sCommand, "rm -f \"%s\"/.*", g_cCurrentIconsPath);
-		cd_debug ("%s", sCommand->str);
-		r = system (sCommand->str);
-		if (r < 0)
-			cd_warning ("Not able to launch this command: %s", sCommand->str);
+		_launch_cmd (sCommand->str);
 		
 		g_string_printf (sCommand, "rm -f \"%s\"/*", g_cCurrentImagesPath);
-		cd_debug ("%s", sCommand->str);
-		r = system (sCommand->str);
-		if (r < 0)
-			cd_warning ("Not able to launch this command: %s", sCommand->str);
+		_launch_cmd (sCommand->str);
 		g_string_printf (sCommand, "rm -f \"%s\"/.*", g_cCurrentImagesPath);
-		cd_debug ("%s", sCommand->str);
-		r = system (sCommand->str);
-		if (r < 0)
-			cd_warning ("Not able to launch this command: %s", sCommand->str);
+		_launch_cmd (sCommand->str);
 	}
 	gchar *cNewLocalIconsPath = g_strdup_printf ("%s/%s", cNewThemePath, CAIRO_DOCK_LOCAL_ICONS_DIR);
-	if (! g_file_test (cNewLocalIconsPath, G_FILE_TEST_IS_DIR))  // c'est un ancien theme, on deplace les icones vers le repertoire 'icons'.
+	if (! g_file_test (cNewLocalIconsPath, G_FILE_TEST_IS_DIR))  // it's an old theme: move icons to a new dir 'icons'.
 	{
 		g_string_printf (sCommand, "find \"%s/%s\" -mindepth 1 ! -name '*.desktop' -exec /bin/cp '{}' '%s' \\;", cNewThemePath, CAIRO_DOCK_LAUNCHERS_DIR, g_cCurrentIconsPath);
 	}
 	else
 	{
-		g_string_printf (sCommand, "for f in \"%s\"/* ; do rm -f \"%s/`basename \"${f%%.*}\"`\"*; done;", cNewLocalIconsPath, g_cCurrentIconsPath);  // on efface les doublons car sinon on pourrait avoir x.png et x.svg ensemble et le dock ne saurait pas lequel choisir.
-		cd_debug ("%s", sCommand->str);
-		r = system (sCommand->str);
-		if (r < 0)
-			cd_warning ("Not able to launch this command: %s", sCommand->str);
+		g_string_printf (sCommand, "for f in \"%s\"/* ; do rm -f \"%s/`basename \"${f%%.*}\"`\"*; done;", cNewLocalIconsPath, g_cCurrentIconsPath);  // we erase double items because we could have x.png and x.svg and the dock will not know which it has to use.
+		_launch_cmd (sCommand->str);
 		
 		g_string_printf (sCommand, "cp \"%s\"/* \"%s\"", cNewLocalIconsPath, g_cCurrentIconsPath);
 	}
-	cd_debug ("%s", sCommand->str);
-	r = system (sCommand->str);
-	if (r < 0)
-		cd_warning ("Not able to launch this command: %s", sCommand->str);
+	_launch_cmd (sCommand->str);
 	g_free (cNewLocalIconsPath);
 	
-	//\___________________ On charge les extras.
+	//\___________________ We load extras.
 	g_string_printf (sCommand, "%s/%s", cNewThemePath, CAIRO_DOCK_LOCAL_EXTRAS_DIR);
 	if (g_file_test (sCommand->str, G_FILE_TEST_IS_DIR))
 	{
 		g_string_printf (sCommand, "cp -r \"%s/%s\"/* \"%s\"", cNewThemePath, CAIRO_DOCK_LOCAL_EXTRAS_DIR, g_cExtrasDirPath);
-		cd_debug ("%s", sCommand->str);
-		r = system (sCommand->str);
-		if (r < 0)
-			cd_warning ("Not able to launch this command: %s", sCommand->str);
+		_launch_cmd (sCommand->str);
 	}
 	
-	//\___________________ On charge les lanceurs si necessaire, en effacant ceux existants.
+	//\___________________ We load launcher if needed after having removed old ones.
 	if (! g_file_test (g_cCurrentLaunchersPath, G_FILE_TEST_EXISTS))
 	{
-		gchar *command = g_strdup_printf ("mkdir -p \"%s\"", g_cCurrentLaunchersPath);
-		r = system (command);
-		if (r < 0)
-			cd_warning ("Not able to launch this command: %s", command);
-		g_free (command);
+		g_string_printf (sCommand, "mkdir -p \"%s\"", g_cCurrentLaunchersPath);
+		_launch_cmd (sCommand->str);
 	}
 	if (g_pMainDock == NULL || bLoadLaunchers)
 	{
 		g_string_printf (sCommand, "rm -f \"%s\"/*.desktop", g_cCurrentLaunchersPath);
-		cd_debug ("%s", sCommand->str);
-		r = system (sCommand->str);
-		if (r < 0)
-			cd_warning ("Not able to launch this command: %s", sCommand->str);
+		_launch_cmd (sCommand->str);
 
 		g_string_printf (sCommand, "cp \"%s/%s\"/*.desktop \"%s\"", cNewThemePath, CAIRO_DOCK_LAUNCHERS_DIR, g_cCurrentLaunchersPath);
-		cd_debug ("%s", sCommand->str);
-		r = system (sCommand->str);
-		if (r < 0)
-			cd_warning ("Not able to launch this command: %s", sCommand->str);
+		_launch_cmd (sCommand->str);
 	}
 	
-	//\___________________ On remplace tous les autres fichiers par les nouveaux.
-	g_string_printf (sCommand, "find \"%s\" -mindepth 1 -maxdepth 1  ! -name '*.conf' -type f -exec rm -f '{}' \\;", g_cCurrentThemePath);  // efface tous les fichiers du theme mais sans toucher aux lanceurs et aux plug-ins.
-	cd_debug ("%s", sCommand->str);
-	r = system (sCommand->str);
-	if (r < 0)
-		cd_warning ("Not able to launch this command: %s", sCommand->str);
+	//\___________________ We replace all files by the new ones.
+	g_string_printf (sCommand, "find \"%s\" -mindepth 1 -maxdepth 1  ! -name '*.conf' -type f -exec rm -f '{}' \\;", g_cCurrentThemePath);  // remove all ficher of the theme except launchers and plugins.
+	_launch_cmd (sCommand->str);
 
 	if (g_pMainDock == NULL || bLoadBehavior)
 	{
-		g_string_printf (sCommand, "find \"%s\"/* -prune ! -name '*.conf' ! -name %s -exec /bin/cp -r '{}' \"%s\" \\;", cNewThemePath, CAIRO_DOCK_LAUNCHERS_DIR, g_cCurrentThemePath);  // copie tous les fichiers du nouveau theme sauf les lanceurs et le .conf, dans le repertoire du theme courant. Ecrase les fichiers de memes noms.
-		cd_debug ("%s", sCommand->str);
-		r = system (sCommand->str);
-		if (r < 0)
-			cd_warning ("Not able to launch this command: %s", sCommand->str);
+		g_string_printf (sCommand, "find \"%s\"/* -prune ! -name '*.conf' ! -name %s -exec /bin/cp -r '{}' \"%s\" \\;", cNewThemePath, CAIRO_DOCK_LAUNCHERS_DIR, g_cCurrentThemePath);  // Copy all files of the new theme except launchers and .conf files in the dir of the current theme. Overwrite files with same names
+		_launch_cmd (sCommand->str);
 	}
 	else
 	{
-		// on copie tous les fichiers du nouveau theme sauf les lanceurs et les .conf (dock et plug-ins).
+		// We copy all files of the new theme except launchers and .conf files (dock and plug-ins).
 		g_string_printf (sCommand, "find \"%s\" -mindepth 1 ! -name '*.conf' ! -path '%s/%s*' ! -type d -exec cp -p {} \"%s\" \\;", cNewThemePath, cNewThemePath, CAIRO_DOCK_LAUNCHERS_DIR, g_cCurrentThemePath);
-		cd_debug ("%s", sCommand->str);
-		r = system (sCommand->str);
-		if (r < 0)
-			cd_warning ("Not able to launch this command: %s", sCommand->str);
+		_launch_cmd (sCommand->str);
 		
-		// on parcours les .conf des plug-ins, on les met a jour, et on fusionne avec le theme courant.
-		gchar *cNewPlugInsDir = g_strdup_printf ("%s/%s", cNewThemePath, CAIRO_DOCK_PLUG_INS_DIR);  // repertoire des plug-ins du nouveau theme.
-		GDir *dir = g_dir_open (cNewPlugInsDir, 0, NULL);  // NULL si ce theme n'a pas de repertoire 'plug-ins'.
+		// iterate all .conf files of all plug-ins, then update them and merge them with the current theme.
+		gchar *cNewPlugInsDir = g_strdup_printf ("%s/%s", cNewThemePath, CAIRO_DOCK_PLUG_INS_DIR);  // dir of plug-ins of the new theme.
+		GDir *dir = g_dir_open (cNewPlugInsDir, 0, NULL);  // NULL if this theme doesn't have any 'plug-ins' dir.
 		const gchar* cModuleDirName;
 		gchar *cConfFilePath, *cNewConfFilePath, *cUserDataDirPath, *cConfFileName;
 		do
 		{
-			cModuleDirName = g_dir_read_name (dir);  // nom du repertoire du theme (pas forcement egal au nom du theme)
+			cModuleDirName = g_dir_read_name (dir);  // name of the dir of the theme (maybe != of theme's name)
 			if (cModuleDirName == NULL)
 				break ;
 			
-			// on cree le repertoire du plug-in dans le theme courant.
+			// we create dir of the plug-in of the current theme.
 			cd_debug ("  installing %s's config", cModuleDirName);
-			cUserDataDirPath = g_strdup_printf ("%s/%s", g_cCurrentPlugInsPath, cModuleDirName);  // repertoire du plug-in dans le theme courant.
+			cUserDataDirPath = g_strdup_printf ("%s/%s", g_cCurrentPlugInsPath, cModuleDirName);  // dir of the plug-in in the current theme.
 			if (! g_file_test (cUserDataDirPath, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR))
 			{
 				cd_debug ("    directory %s doesn't exist, it will be created.", cUserDataDirPath);
 				
 				g_string_printf (sCommand, "mkdir -p \"%s\"", cUserDataDirPath);
-				r = system (sCommand->str);
-				if (r < 0)
-					cd_warning ("Not able to launch this command: %s", sCommand->str);
+				_launch_cmd (sCommand->str);
 			}
 			
-			// on recupere le nom et le chemin du .conf du plug-in dans le nouveau theme.
+			// we find the name and path of the .conf file of the plugin in the new theme.
 			cConfFileName = g_strdup_printf ("%s.conf", cModuleDirName);
 			cNewConfFilePath = g_strdup_printf ("%s/%s/%s", cNewPlugInsDir, cModuleDirName, cConfFileName);
 			if (! g_file_test (cNewConfFilePath, G_FILE_TEST_EXISTS))
 			{
 				g_free (cConfFileName);
 				g_free (cNewConfFilePath);
-				CairoDockModule *pModule = cairo_dock_foreach_module ((GHRFunc) _find_module_from_user_data_dir, (gpointer) cModuleDirName);
-				if (pModule == NULL)  // du coup, dans ce cas-la, on ne charge pas des plug-ins non utilises par l'utilisateur.
+				GldiModule *pModule = gldi_module_foreach ((GHRFunc) _find_module_from_user_data_dir, (gpointer) cModuleDirName);
+				if (pModule == NULL)  // in this case, we don't load non used plugins.
 				{
 					cd_warning ("couldn't find the module owning '%s', this file will be ignored.");
 					continue;
@@ -611,9 +595,9 @@ static gboolean _cairo_dock_import_local_theme (const gchar *cNewThemePath, gboo
 				cConfFileName = g_strdup (pModule->pVisitCard->cConfFileName);
 				cNewConfFilePath = g_strdup_printf ("%s/%s/%s", cNewPlugInsDir, cModuleDirName, cConfFileName);
 			}
-			cConfFilePath = g_strdup_printf ("%s/%s", cUserDataDirPath, cConfFileName);  // chemin du .conf dans le theme courant.
+			cConfFilePath = g_strdup_printf ("%s/%s", cUserDataDirPath, cConfFileName);  // path of the .conf file of the current theme.
 			
-			// on fusionne les 2 .conf.
+			// we merge these 2 .conf files.
 			if (! g_file_test (cConfFilePath, G_FILE_TEST_EXISTS))
 			{
 				cd_debug ("    no conf file %s, we will take the theme's one", cConfFilePath);
@@ -634,15 +618,11 @@ static gboolean _cairo_dock_import_local_theme (const gchar *cNewThemePath, gboo
 	}
 	
 	g_string_printf (sCommand, "rm -f \"%s/last-modif\"", g_cCurrentThemePath);
-	r = system (sCommand->str);
-	if (r < 0)
-		cd_warning ("Not able to launch this command: %s", sCommand->str);
+	_launch_cmd (sCommand->str);
 	
-	// precaution probablement inutile.
+	// precaution maybe useless.
 	g_string_printf (sCommand, "chmod -R 775 \"%s\"", g_cCurrentThemePath);
-	r = system (sCommand->str);
-	if (r < 0)
-		cd_warning ("Not able to launch this command: %s", sCommand->str);
+	_launch_cmd (sCommand->str);
 	
 	cairo_dock_mark_current_theme_as_modified (FALSE);
 	
@@ -693,7 +673,7 @@ static void _discard_import (gpointer *pSharedMemory)
 	g_free (pSharedMemory[0]);
 	g_free (pSharedMemory);
 }
-CairoDockTask *cairo_dock_import_theme_async (const gchar *cThemeName, gboolean bLoadBehavior, gboolean bLoadLaunchers, GFunc pCallback, gpointer data)
+GldiTask *cairo_dock_import_theme_async (const gchar *cThemeName, gboolean bLoadBehavior, gboolean bLoadLaunchers, GFunc pCallback, gpointer data)
 {
 	gpointer *pSharedMemory = g_new0 (gpointer, 5);
 	pSharedMemory[0] = g_strdup (cThemeName);
@@ -701,8 +681,8 @@ CairoDockTask *cairo_dock_import_theme_async (const gchar *cThemeName, gboolean
 	pSharedMemory[2] = GINT_TO_POINTER (bLoadLaunchers);
 	pSharedMemory[3] = pCallback;
 	pSharedMemory[4] = data;
-	CairoDockTask *pTask = cairo_dock_new_task_full (0, (CairoDockGetDataAsyncFunc) _import_theme, (CairoDockUpdateSyncFunc) _finish_import, (GFreeFunc) _discard_import, pSharedMemory);
-	cairo_dock_launch_task (pTask);
+	GldiTask *pTask = gldi_task_new_full (0, (GldiGetDataAsyncFunc) _import_theme, (GldiUpdateSyncFunc) _finish_import, (GFreeFunc) _discard_import, pSharedMemory);
+	gldi_task_launch (pTask);
 	return pTask;
 }
 
